SystemOrganization addCategory: #ConfigurationOfSeaside30!

Object subclass: #ConfigurationOfSeaside30
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeaside30'!

!ConfigurationOfSeaside30 commentStamp: 'pmm 9/1/2012 10:56' prior: 0!
The following load expression will load the 'default' group for Seaside3.0:

   (ConfigurationOfSeaside30 project version: '3.1') load.

   alternatively you can also load the stable version using:
	 (ConfigurationOfSeaside30 project version: #stable) load.

By default all of the packages and projects associated with the Seaside30 
project will be loaded.

Here is the list of groups for Seaside 3.0:
   - 'Core'
   - 'Tests'
   - 'Examples'
   - 'Development'
   - 'Development Tests'
   - 'Production' (GemStone only)
   - 'Javascript'
   - 'Javascript Tests'
   - 'JQuery'
   - 'JQuery Tests'
   - 'JQueryUI'
   - 'JQueryUI Tests'
   - 'JQueryUI Examples'
   - 'JSON'
   - 'JSON Tests'
   - 'OmniBrowser'
   - 'RSS'
   - 'RSS Tests'
   - 'RSS Examples'
   - 'Scriptaculous'
   - 'Scriptaculous Tests'
   - 'Welcome'
   - 'Welcome Tests'
   - 'OneClick'
   - 'Comet' 
   - 'Comet Tests'
   - 'Comet Examples'
   - 'Filesystem'
   - 'Filesystem Tests'

And the following groups are for loading adapters.

   - 'Comanche' and 'Kom'
   - 'FastCGI'
   - 'Swazoo'
   - 'WebClient'
   - 'Zinc'

The '... Tests' group include the test packages for the named group. Usually there is no benefit in loading these unless to want to work on those packages.
The '... Examples' group include the examples packages for the named group

   - 'Core' is the absolute minimum set of packages that should be
     loaded to get expected Seaside functionality
   - 'Development' adds in the Seaside development tools. It should be
     noted that it is not recommended that the Seaside development tools
     be loaded in a production image, because the tools are not considered
     essential or safe.
   - 'OmniBrowser' loads OmniBrowser as well as related tools like the
     server browser.
   - The other groups should be more or less self explanatory.

It is recommended that you load the 'Core' group and groups for the
additional functionality that you need.

You must choose at least one adaptor (Seaside-Adaptors-Swazoo or Seaside-Adaptors-Comanche), so in 
theory the absolute minimum loadable unit for Seaside30 would be:

   (ConfigurationOfSeaside30 project version: '3.1.0)
     load: #('Core' 'Kom').

Note that there are no pre-defined components registered in this case, 
so even if you manually start WAKom:

   WAKom startOn: 8080

the only page you can hit is the files page:

   http://localhost:8080/files

You could load the example packages:

  (ConfigurationOfSeaside30 project version: '3.1')
     load: #('Examples').

to have a few more pages to hit:

   http://localhost:8080/examples/examplebrowser

but without the familiar development tools you might not have an 
enjoyable experience. You can add in the development tools with the 
following expression:

  (ConfigurationOfSeaside30 project version: '3.1.0')
     load: #('Development').

Only then will you see the familiar Dispatcher page when you hit:

   http://localhost:8080/

At this point in time, the only things that you won't have loaded 
(because of package dependencies) are:

   - Comet
   - Swazoo
   - RSS support
   - javascript support
   - HTML5 support
   - EMail
   - Welcome page

To add the remaining pieces you'd now have to list the individual 
packages!

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'NickAger 3/23/2012 16:50'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfSeaside30 class methodsFor: 'private' stamp: 'dkh 11/05/2009 16:55'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 1/14/2011 11:50'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 13:20'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 13:20'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 2/9/2011 11:39'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 2/9/2011 11:42'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 1/11/2011 15:01'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfSeaside30 class methodsFor: 'private' stamp: 'DaleHenrichs 06/20/2010 16:22'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfSeaside30 class methodsFor: 'metacello tool support' stamp: 'dkh 11/05/2009 16:55'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSeaside30 class methodsFor: 'metacello tool support' stamp: 'dkh 11/13/2009 16:33'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSeaside30 class methodsFor: 'loading' stamp: 'DaleHenrichs 12/19/2009 10:53'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfSeaside30 class methodsFor: 'loading' stamp: 'dkh 11/05/2009 16:55'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfSeaside30 class methodsFor: 'metacello tool support' stamp: 'dkh 11/13/2009 16:33'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSeaside30 class methodsFor: 'accessing' stamp: 'dkh 11/05/2009 16:55'!
project

	^self new project! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 1/11/2011 15:05'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:56'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:56'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:56'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 02/11/2011 17:42'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfSeaside30 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:57'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 11/5/2010 16:24'!
baseline300: spec 
	<version: '3.0.0-baseline' imports: #( '3.0.0-rc.2-commonBaseline' )>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: '- ported Seaside-FileSystem to GemStone (GemStone Issue 165)'.
		spec
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			yourself.
		spec
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 
				'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 
				'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web'  
				'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 
				'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 
				'Seaside-Tests-Email' 'Seaside-Tests-Functional'  
				'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 
				'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 
				'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 
				'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0.6-baseline';
					file: 'ConfigurationOfKomHttpServer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31-baseline';
					file: 'ConfigurationOfSPort2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Canvas' 
				with: [ spec includes: #('Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ 
				spec 
					requires: #( 'OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core') ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ spec requires: #('SPort2' ). ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Javascript-Tests-Pharo-Core' 
				with: [ spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];	
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #( 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 
				'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 
				'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web'  
				'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 
				'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 
				
				 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 
				'Seaside-Tests-Email' 'Seaside-Tests-Functional'  
				'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 
				'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 
				'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 
				'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
				yourself ].

	spec for: #pharo do: [
		spec
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [ 
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ];
			yourself.
		spec
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease Slime'). ];
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ) ];
			yourself. 

		spec
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' );
			yourself. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsCore';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: '0.231-baseline';
					loads: #('FastCGI' );
					file: 'ConfigurationOfGsFastCGI';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Development' with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production') ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Seaside-Canvas' 
				with: [ spec file: 'Seaside-Canvas.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' 'GsCore' ) ];
			package: 'Seaside-GemStone-Development' with: [
				 spec 
					requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 
								'Seaside-GemStone-Tools-Production' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-GemStone-Continuation' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Production'
				with: [spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development')];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];

			package: 'Seaside-FileSystem' 
				with: [ spec file:  'Seaside-FileSystem.gemstone'. ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. 

		spec
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' );
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone240-Core' ) ];
			package: 'Seaside-GemStone240-Core' with: [ 
				spec 
					includes: #('Seaside-GemStone-Core' );
					requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' with: [ 
				spec requires: #('Seaside-GemStone240-Core' ) ];

			yourself.].
	spec for: #'gs3.x' do: [
		spec
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone300-Core' ) ];
			package: 'Seaside-GemStone300-Core' with: [ 
				spec 
					includes: #('Seaside-GemStone-Core' );
					requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' with: [ 
				spec requires: #('Seaside-GemStone300-Core' ) ];
			yourself.].! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 2/5/2010 22:28'!
baseline300alpha500: spec 
	<version: '3.0.0-alpha5-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: '3.0.0 baseline based on 3.0.0-alpha5'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha1-baseline';
					loads: #('Grease-Core' );
					projectPackage: [
						spec
							name: 'ConfigurationOfGrease';
							repository: 'http://seaside.gemstone.com/ss/Seaside30' ]];
			project: 'Grease Tests'
				copyFrom: 'Grease'
				with: [ 
					spec 
						versionString: '1.0-alpha1-baseline';
						loads: #('Grease-Tests-Core' ) ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ spec includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease') ];
			package: 'Seaside-Pharo-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease' ). ];

			package: 'DynamicBindings'  
				with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'KomServices'  
				with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'KomHttpServer'  
				with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'DynamicBindings' 'KomServices' 'KomHttpServer' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Sport-2' 
				with: [ spec repository: 'http://www.squeaksource.com/SPort'. ];
			package: 'Swazoo-2' 
				with: [ spec 
					file: 'Swazoo-2.2'; "load latest picks up Swazoo-2.03, which fails to load"
					requires: #('Sport-2' );
					repository: 'http://www.squeaksource.com/Swazoo'. ];
			package: 'Seaside-Swazoo'  
				with: [ spec 
					requires: #('Grease' 'Swazoo-2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'Sport-2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];
			
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' ) ];
			yourself.
					
		"fix: http://code.google.com/p/seaside/issues/detail?id=484"
		spec
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' 'Seaside-Tests-UTF8' ) ];	
			package: 'Seaside-Tests-Core'
				with: [ spec includes: #('Seaside-Tests-UTF8' 'Seaside-Tests-Pharo-Core' ). ];
			yourself. ].

	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					loads: #('FastCGI' );
					projectPackage: [
						spec
							name: 'ConfigurationOfGsFastCGI';
							repository: 'http://seaside.gemstone.com/ss/fastcgi' ]];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ spec includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'JQuery-Tests-Core'
				with: [ spec includes: #('JQuery-Tests-GemStone-Core' ) ];
			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'Seaside-Tests-UTF8'  
				with: [ spec includes: #('Seaside-Tests-GemStone-UTF8' ). ];
			
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-GemStone-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-GemStone-Tools-Web' 'Seaside-GemStone-Flow' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-GemStone-Continuation' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];

		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			
			package: 'JQuery-Tests-GemStone-Core'
				with: [ spec requires: #('JQuery-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			package: 'Seaside-Tests-GemStone-UTF8'  
				with: [ spec requires: #('Seaside-Tests-UTF8' ) ];
			yourself. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 1/13/2010 20:44'!
baseline300alpha501: spec 
	<version: '3.0.0-alpha5.1-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: '3.0.0 baseline based on 3.0.0-alpha5'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha1-baseline';
					loads: #('Grease-Core' );
					projectPackage: [
						spec
							name: 'ConfigurationOfGrease';
							repository: 'http://seaside.gemstone.com/ss/Seaside30' ]];
			project: 'Grease Tests'
				copyFrom: 'Grease'
				with: [ 
					spec 
						versionString: '1.0-alpha1-baseline';
						loads: #('Grease-Tests-Core' ) ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ spec includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease') ];
			package: 'Seaside-Pharo-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease' ). ];

			package: 'DynamicBindings'  
				with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'KomServices'  
				with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'KomHttpServer'  
				with: [ spec repository: 'http://www.squeaksource.com/KomHttpServer' ];
			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'DynamicBindings' 'KomServices' 'KomHttpServer' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Sport-2' 
				with: [ spec repository: 'http://www.squeaksource.com/SPort'. ];
			package: 'Swazoo-2' 
				with: [ spec 
					file: 'Swazoo-2.2'; "load latest picks up Swazoo-2.03, which fails to load"
					requires: #('Sport-2' );
					repository: 'http://www.squeaksource.com/Swazoo'. ];
			package: 'Seaside-Swazoo'  
				with: [ spec 
					requires: #('Grease' 'Swazoo-2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'Sport-2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];
			
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' ) ];
			yourself. ].

	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					loads: #('FastCGI' );
					projectPackage: [
						spec
							name: 'ConfigurationOfGsFastCGI';
							repository: 'http://seaside.gemstone.com/ss/fastcgi' ]];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					projectPackage: [
						spec
							name: 'ConfigurationOfGsOB';
							repository: 'http://seaside.gemstone.com/ss/GemStone' ]];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-Core' 
				with: [ spec file: 'JQuery-Core.gemstone' ];
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Core' 
				with: [ spec file: 'Prototype-Core.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-Session' 
				with: [ spec file: 'Seaside-Session.gemstone' ];

		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow';
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];

			package: 'JQuery-Tests-Core'
				with: [ spec includes: #('JQuery-Tests-GemStone-Core' ) ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];

			package: 'Seaside-GemStone-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-GemStone-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-GemStone-Continuation' ) ];

			package: 'JQuery-Tests-GemStone-Core'
				with: [ spec requires: #('JQuery-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			yourself.].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 1/13/2010 20:44'!
baseline300alpha502: spec 
	<version: '3.0.0-alpha5.2-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: '3.0.0 baseline based on 3.0.0-alpha5'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha1-baseline';
					loads: #('Grease-Core' );
					projectPackage: [
						spec
							name: 'ConfigurationOfGrease';
							repository: 'http://seaside.gemstone.com/ss/Seaside30' ]];
			project: 'Grease Tests'
				copyFrom: 'Grease'
				with: [ 
					spec 
						versionString: '1.0-alpha1-baseline';
						loads: #('Grease-Tests-Core' ) ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0';
					projectPackage: [
						spec
							name: 'ConfigurationOfKomHttpServer';
							repository: 'http://seaside.gemstone.com/ss/Seaside30' ]];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					projectPackage: [
						spec
							name: 'ConfigurationOfSPort2';
							repository: 'http://seaside.gemstone.com/ss/Seaside30' ]];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2';
					projectPackage: [
						spec
							name: 'ConfigurationOfSwazoo2';
							repository: 'http://seaside.gemstone.com/ss/Seaside30' ]];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ spec includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease') ];
			package: 'Seaside-Pharo-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease' ). ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-Swazoo'  
				with: [ spec 
					requires: #('Grease' 'Swazoo2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'SPort2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];
			
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' ) ];
			yourself. ].

	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					loads: #('FastCGI' );
					projectPackage: [
						spec
							name: 'ConfigurationOfGsFastCGI';
							repository: 'http://seaside.gemstone.com/ss/fastcgi' ]];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					projectPackage: [
						spec
							name: 'ConfigurationOfGsOB';
							repository: 'http://seaside.gemstone.com/ss/GemStone' ]];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-Core' 
				with: [ spec file: 'JQuery-Core.gemstone' ];
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Core' 
				with: [ spec file: 'Prototype-Core.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-Session' 
				with: [ spec file: 'Seaside-Session.gemstone' ];

		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow';
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];

			package: 'JQuery-Tests-Core'
				with: [ spec includes: #('JQuery-Tests-GemStone-Core' ) ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];

			package: 'Seaside-GemStone-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-GemStone-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-GemStone-Continuation' ) ];

			package: 'JQuery-Tests-GemStone-Core'
				with: [ spec requires: #('JQuery-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			yourself.].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 1/13/2010 20:44'!
baseline300alpha503: spec 
	<version: '3.0.0-alpha5.3-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: '3.0.0 baseline based on 3.0.0-alpha5'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha1-baseline';
					loads: #('Grease-Core' );
					projectPackage: [
						spec
							name: 'ConfigurationOfGrease';
							repository: 'http://seaside.gemstone.com/ss/Seaside30' ]];
			project: 'Grease Tests'
				copyFrom: 'Grease'
				with: [ 
					spec 
						versionString: '1.0-alpha1-baseline';
						loads: #('Grease-Tests-Core' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2';
					projectPackage: [
						spec
							name: 'ConfigurationOfSwazoo2';
							repository: 'http://www.squeaksource.com/MetacelloRepository' ]];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Seaside-Swazoo'  
				with: [ spec 
					requires: #('Grease' 'Swazoo2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0';
					projectPackage: [
						spec
							name: 'ConfigurationOfKomHttpServer';
							repository: 'http://www.squeaksource.com/MetacelloRepository' ]];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					projectPackage: [
						spec
							name: 'ConfigurationOfSPort2';
							repository: 'http://www.squeaksource.com/MetacelloRepository' ]];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ spec includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease') ];
			package: 'Seaside-Pharo-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease' ). ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'SPort2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];
			
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' ) ];
			yourself. ].

	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					loads: #('FastCGI' );
					projectPackage: [
						spec
							name: 'ConfigurationOfGsFastCGI';
							repository: 'http://seaside.gemstone.com/ss/fastcgi' ]];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					projectPackage: [
						spec
							name: 'ConfigurationOfGsOB';
							repository: 'http://seaside.gemstone.com/ss/GemStone' ]];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-Core' 
				with: [ spec file: 'JQuery-Core.gemstone' ];
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Core' 
				with: [ spec file: 'Prototype-Core.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-Session' 
				with: [ spec file: 'Seaside-Session.gemstone' ];

		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow';
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];

			package: 'JQuery-Tests-Core'
				with: [ spec includes: #('JQuery-Tests-GemStone-Core' ) ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];

			package: 'Seaside-GemStone-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-GemStone-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-GemStone-Continuation' ) ];

			package: 'JQuery-Tests-GemStone-Core'
				with: [ spec requires: #('JQuery-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			yourself.].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 1/13/2010 20:45'!
baseline300alpha504: spec 
	<version: '3.0.0-alpha5.4-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: '3.0.0 baseline based on 3.0.0-alpha5'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha1-baseline';
					loads: #('Grease-Core' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Tests'
				copyFrom: 'Grease'
				with: [ 
					spec 
						versionString: '1.0-alpha1-baseline';
						loads: #('Grease-Tests-Core' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2';
					file: 'ConfigurationOfSwazoo2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Seaside-Swazoo'  
				with: [ spec 
					requires: #('Grease' 'Swazoo2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0';
					file: 'ConfigurationOfKomHttpServer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					file: 'ConfigurationOfSPort2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ spec includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease') ];
			package: 'Seaside-Pharo-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease' ). ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'SPort2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];
			
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' ) ];
			yourself. ].

	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					loads: #('FastCGI' );
					file: 'ConfigurationOfGsFastCGI';
					repository: 'http://seaside.gemstone.com/ss/fastcgi' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/GemStone' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-Core' 
				with: [ spec file: 'JQuery-Core.gemstone' ];
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Core' 
				with: [ spec file: 'Prototype-Core.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow';
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];

			package: 'JQuery-Tests-Core'
				with: [ spec includes: #('JQuery-Tests-GemStone-Core' ) ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];

			package: 'Seaside-GemStone-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-GemStone-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-GemStone-Continuation' ) ];

			package: 'JQuery-Tests-GemStone-Core'
				with: [ spec requires: #('JQuery-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			yourself.].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 11/5/2010 16:24'!
baseline300alpha505: spec 
	<version: '3.0.0-alpha5.5-baseline' imports: #( '3.0.0-alpha5.5-commonBaseline' )>

	spec for: #squeakCommon do: [
		spec blessing: #baseline.
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0';
					file: 'ConfigurationOfKomHttpServer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					loads: #('Refactoring-Core' );
					file: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					file: 'ConfigurationOfSPort2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ spec includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease') ];
			package: 'Seaside-Pharo-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease' ). ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'SPort2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];
			
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' ) ];
			yourself. 
			
		spec
			group: 'default' with: #('Seaside-Pharo-Continuation' 'Seaside-Core' 'Seaside-Pharo-Core' 'Seaside-Component' 'Seaside-Canvas' 'RSS-Core' 'Javascript-Core' 'Javascript-Pharo-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-Pharo-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Session' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Pharo-Flow' 'Seaside-Examples' 'RSS-Examples'  'Seaside-Widgets' 'Seaside-Tools-Web' 'Seaside-Development' 'Seaside-Environment' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'RSS-Tests-Core' 'Seaside-Tests-Core' 'Seaside-Tests-Pharo-Core' 'Seaside-Tests-Component' 'Seaside-Tests-Canvas' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Seaside-Tests-Flow' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Session' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Development' 'Seaside-Tests-UTF8' 'Seaside-Pharo-Canvas' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Functional' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Development' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Pharo-Core' 'Comet-Examples' 'Seaside-FileSystem' 'Seaside-Tests-FileSystem' 'Comet-Tests-Core' 'Seaside-Tests-Pharo-Continuation' 'Seaside-Tests-Pharo-Development' 'Seaside-Tests-Adaptors-Comanche' );
			yourself.

		spec for: #OBPresent do: [
			spec
				group: 'default' with: #('Seaside-Tools-OmniBrowser' 'Seaside-Pharo-Tools-OmniBrowser' )
				yourself ].

		spec for: #OBNotPresent do: [
			spec 
				package: 'Seaside-Tools-OmniBrowser' 
					with: [ spec requires: #('OB' ). ];
				package: 'Seaside-Pharo-Tools-OmniBrowser'  
					with: [ spec requires: #('OB' ) ];
				yourself ].

		spec for: #RBPresent do: [
			spec
				group: 'default' with: #('Seaside-Slime' 'Seaside-Tests-Slime' )
				yourself ].

		spec for: #RBNotPresent do: [
			spec 
				package: 'Seaside-Slime' with: [
					 spec 
						requires: #('Refactoring-Core' ) ];
				yourself ]].

	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					loads: #('FastCGI' );
					file: 'ConfigurationOfGsFastCGI';
					repository: 'http://seaside.gemstone.com/ss/fastcgi' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/GemStone' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-Core' 
				with: [ spec file: 'JQuery-Core.gemstone' ];
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Core' 
				with: [ spec file: 'Prototype-Core.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow';
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];

			package: 'JQuery-Tests-Core'
				with: [ spec includes: #('JQuery-Tests-GemStone-Core' ) ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];

			package: 'Seaside-GemStone-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-GemStone-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-GemStone-Continuation' ) ];

			package: 'JQuery-Tests-GemStone-Core'
				with: [ spec requires: #('JQuery-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			yourself.].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 11/18/2010 09:51'!
baseline300alpha505Common: spec 
	<version: '3.0.0-alpha5.5-commonBaseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Add in OB dependencies'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha1-baseline';
					loads: #('Grease-Core' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Tests'
				copyFrom: 'Grease'
				with: [ 
					spec 
						versionString: '1.0-alpha1-baseline';
						loads: #('Grease-Tests-Core' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2';
					file: 'ConfigurationOfSwazoo2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Seaside-Swazoo'  
				with: [ spec 
					requires: #('Grease' 'Swazoo2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself. ].

! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 1/26/2010 15:32'!
baseline300alpha506: spec 
	<version: '3.0.0-alpha5.6-baseline' imports: #( '3.0.0-alpha5.6-commonBaseline' )>

	spec for: #common do: [
		spec
			group: 'Core' with: #('Seaside-Core' 'Seaside-Component' 'Seaside-Canvas' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Session' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Examples' 'RSS-Examples'  'Seaside-Widgets' 'Seaside-Tools-Web' 'Seaside-Development' 'Seaside-Environment' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Tools-OmniBrowser'  );
			group: 'Tests' with: #('RSS-Tests-Core' 'Seaside-Tests-Core' 'Seaside-Tests-Component' 'Seaside-Tests-Canvas' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Seaside-Tests-Flow' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Session' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Development' 'Seaside-Tests-UTF8' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0';
					file: 'ConfigurationOfKomHttpServer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					file: 'ConfigurationOfSPort2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ 
				spec 
					requires: #( 'OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease') ];
			package: 'Seaside-Pharo-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'SPort2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];	
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Pharo-Continuation' 'Seaside-Pharo-Core' 'Javascript-Pharo-Core' 'Seaside-Pharo-Email' 'Seaside-Pharo-Flow' 'Seaside-Pharo-Canvas' 'Seaside-Pharo-Environment' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Development' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Pharo-Core' 'Comet-Examples' 'Seaside-FileSystem' 'Seaside-Pharo-Tools-OmniBrowser' );
			group: 'Tests' with: #('Seaside-Tests-Pharo-Core' 'Seaside-Tests-Pharo-Functional' 'Seaside-Tests-FileSystem' 'Comet-Tests-Core' 'Seaside-Tests-Pharo-Continuation' 'Seaside-Tests-Pharo-Development' 'Seaside-Tests-Adaptors-Comanche' );
				yourself ].

	spec for: #pharo do: [
		"RBParseTreeSearcher only in Pharo AST code base at the moment, so Slime is Pharo-specific"
		spec
			project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					loads: #('Refactoring-Core' );
					file: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease' 'Refactoring-Core'). ];
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Refactoring-Core' ) ];
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Slime'  );
			group: 'Tests' with: #('Seaside-Tests-Slime' );
			yourself. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					loads: #('FastCGI' );
					file: 'ConfigurationOfGsFastCGI';
					repository: 'http://seaside.gemstone.com/ss/fastcgi' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/GemStone' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-Core' 
				with: [ spec file: 'JQuery-Core.gemstone' ];
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Core' 
				with: [ spec file: 'Prototype-Core.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow';
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];

			package: 'JQuery-Tests-Core'
				with: [ spec includes: #('JQuery-Tests-GemStone-Core' ) ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];

			package: 'Seaside-GemStone-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-GemStone-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-GemStone-Continuation' ) ];

			package: 'JQuery-Tests-GemStone-Core'
				with: [ spec requires: #('JQuery-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			yourself.].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 11/18/2010 09:51'!
baseline300alpha506Common: spec 
	<version: '3.0.0-alpha5.6-commonBaseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Add in OB dependencies'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha2-baseline';
					loads: #('Grease-Core' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Tests'
				copyFrom: 'Grease'
				with: [ 
					spec 
						versionString: '1.0-alpha2-baseline';
						loads: #('Grease-Tests-Core' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2';
					file: 'ConfigurationOfSwazoo2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Seaside-Swazoo'  
				with: [ 
					spec 
						requires: #('Grease' 'Swazoo2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself. ].

! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 1/27/2010 15:52'!
baseline300alpha507: spec 
	<version: '3.0.0-alpha5.7-baseline' imports: #( '3.0.0-alpha5.7-commonBaseline' )>

	spec for: #common do: [
		spec
			group: 'Core' with: #('Seaside-Core' 'Seaside-Component' 'Seaside-Canvas' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Session' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Examples' 'RSS-Examples'  'Seaside-Widgets' 'Seaside-Tools-Web' 'Seaside-Development' 'Seaside-Environment' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Tools-OmniBrowser'  );
			group: 'Tests' with: #('RSS-Tests-Core' 'Seaside-Tests-Core' 'Seaside-Tests-Component' 'Seaside-Tests-Canvas' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Seaside-Tests-Flow' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Session' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Development' 'Seaside-Tests-UTF8' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0';
					file: 'ConfigurationOfKomHttpServer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					file: 'ConfigurationOfSPort2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ 
				spec 
					requires: #( 'OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease') ];
			package: 'Seaside-Pharo-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'SPort2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];	
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Pharo-Continuation' 'Seaside-Pharo-Core' 'Javascript-Pharo-Core' 'Seaside-Pharo-Email' 'Seaside-Pharo-Flow' 'Seaside-Pharo-Canvas' 'Seaside-Pharo-Environment' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Development' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Pharo-Core' 'Comet-Examples' 'Seaside-FileSystem' 'Seaside-Pharo-Tools-OmniBrowser' );
			group: 'Tests' with: #('Seaside-Tests-Pharo-Core' 'Seaside-Tests-Pharo-Functional' 'Seaside-Tests-FileSystem' 'Comet-Tests-Core' 'Seaside-Tests-Pharo-Continuation' 'Seaside-Tests-Pharo-Development' 'Seaside-Tests-Adaptors-Comanche' );
				yourself ].

	spec for: #pharo do: [
		spec
			project: 'Grease-Slime' with: [
				spec
					className: 'ConfigurationOfGrease';
					loads: #('Grease-Slime' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease-Tests-Slime' copyFrom: 'Grease-Slime' with: [
				spec loads: #('Grease-Tests-Slime' ) ];
			yourself.
		spec
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease-Slime'). ];
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease-Tests-Slime' ) ];
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Slime'  );
			group: 'Tests' with: #('Seaside-Tests-Slime' );
			yourself. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					loads: #('FastCGI' );
					file: 'ConfigurationOfGsFastCGI';
					repository: 'http://seaside.gemstone.com/ss/fastcgi' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/GemStone' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-Core' 
				with: [ spec file: 'JQuery-Core.gemstone' ];
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Core' 
				with: [ spec file: 'Prototype-Core.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow';
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];

			package: 'JQuery-Tests-Core'
				with: [ spec includes: #('JQuery-Tests-GemStone-Core' ) ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];

			package: 'Seaside-GemStone-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-GemStone-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-GemStone-Continuation' ) ];

			package: 'JQuery-Tests-GemStone-Core'
				with: [ spec requires: #('JQuery-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			yourself.].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 11/18/2010 09:51'!
baseline300alpha507Common: spec 
	<version: '3.0.0-alpha5.7-commonBaseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Add in OB dependencies'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha5-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Tests'
				copyFrom: 'Grease'
				with: [ 
					spec 
						versionString: '1.0-alpha5-baseline';
						loads: #('Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2';
					file: 'ConfigurationOfSwazoo2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Seaside-Swazoo'  
				with: [ 
					spec 
						requires: #('Grease' 'Swazoo2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself. ].

! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 3/1/2010 13:54'!
baseline300alpha509: spec 
	<version: '3.0.0-alpha5.9-baseline' imports: #( '3.0.0-alpha5.9-commonBaseline' )>

	spec for: #common do: [
		spec
			group: 'Core' with: #('Seaside-Core' 'Seaside-Component' 'Seaside-Canvas' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Session' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Examples' 'RSS-Examples'  'Seaside-Widgets' 'Seaside-Tools-Web' 'Seaside-Development' 'Seaside-Environment' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Tools-OmniBrowser'  );
			group: 'Tests' with: #('RSS-Tests-Core' 'Seaside-Tests-Core' 'Seaside-Tests-Component' 'Seaside-Tests-Canvas' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Seaside-Tests-Flow' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Session' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Development' 'Seaside-Tests-UTF8' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfKomHttpServer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31-baseline';
					file: 'ConfigurationOfSPort2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ 
				spec 
					requires: #( 'OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease') ];
			package: 'Seaside-Pharo-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'SPort2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];	
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Pharo-Continuation' 'Seaside-Pharo-Core' 'Javascript-Pharo-Core' 'Seaside-Pharo-Email' 'Seaside-Pharo-Flow' 'Seaside-Pharo-Canvas' 'Seaside-Pharo-Environment' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Development' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Pharo-Core' 'Comet-Examples' 'Seaside-FileSystem' 'Seaside-Pharo-Tools-OmniBrowser' );
			group: 'Tests' with: #('Seaside-Tests-Pharo-Core' 'Seaside-Tests-Pharo-Functional' 'Seaside-Tests-FileSystem' 'Comet-Tests-Core' 'Seaside-Tests-Pharo-Continuation' 'Seaside-Tests-Pharo-Development' 'Seaside-Tests-Adaptors-Comanche' );
				yourself ].

	spec for: #pharo do: [
		spec
			project: 'Grease-Slime' with: [
				spec
					className: 'ConfigurationOfGrease';
					loads: #('Grease-Slime' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease-Tests-Slime' copyFrom: 'Grease-Slime' with: [
				spec loads: #('Grease-Tests-Slime' ) ];
			yourself.
		spec
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease-Slime'). ];
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease-Tests-Slime' ) ];
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Slime'  );
			group: 'Tests' with: #('Seaside-Tests-Slime' );
			yourself. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					loads: #('FastCGI' );
					file: 'ConfigurationOfGsFastCGI';
					repository: 'http://seaside.gemstone.com/ss/fastcgi' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/GemStone' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-Core' 
				with: [ spec file: 'JQuery-Core.gemstone' ];
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Core' 
				with: [ spec file: 'Prototype-Core.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow';
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];

			package: 'JQuery-Tests-Core'
				with: [ spec includes: #('JQuery-Tests-GemStone-Core' ) ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];

			package: 'Seaside-GemStone-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-GemStone-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-GemStone-Continuation' ) ];

			package: 'JQuery-Tests-GemStone-Core'
				with: [ spec requires: #('JQuery-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			yourself.].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 11/18/2010 09:51'!
baseline300alpha509Common: spec 
	<version: '3.0.0-alpha5.9-commonBaseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'fix project versions'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha5-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Tests'
				copyFrom: 'Grease'
				with: [ 
					spec 
						versionString: '1.0-alpha5-baseline';
						loads: #('Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2.0.2-baseline';
					file: 'ConfigurationOfSwazoo2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Seaside-Swazoo'  
				with: [ 
					spec 
						requires: #('Grease' 'Swazoo2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself. ].

! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 4/9/2010 16:17'!
baseline300alpha511: spec 
	<version: '3.0.0-alpha5.11-baseline' imports: #( '3.0.0-alpha5.11-commonBaseline' )>

	spec for: #common do: [
		spec
			group: 'Core' with: #('Seaside-Core' 'Seaside-Component' 'Seaside-Canvas' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Session' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Examples' 'RSS-Examples'  'Seaside-Widgets' 'Seaside-Tools-Web' 'Seaside-Development' 'Seaside-Environment' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Tools-OmniBrowser'  );
			group: 'Tests' with: #('RSS-Tests-Core' 'Seaside-Tests-Core' 'Seaside-Tests-Component' 'Seaside-Tests-Canvas' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Seaside-Tests-Flow' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Session' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Development' 'Seaside-Tests-UTF8' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfKomHttpServer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31-baseline';
					file: 'ConfigurationOfSPort2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ 
				spec 
					requires: #( 'OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease') ];
			package: 'Seaside-Pharo-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'SPort2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Javascript-Tests-Pharo-Core' 
				with: [ spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];	
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Pharo-Continuation' 'Seaside-Pharo-Core' 'Javascript-Pharo-Core' 'Seaside-Pharo-Email' 'Seaside-Pharo-Flow' 'Seaside-Pharo-Canvas' 'Seaside-Pharo-Environment' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Development' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Pharo-Core' 'Comet-Examples' 'Seaside-FileSystem' 'Seaside-Pharo-Tools-OmniBrowser' );
			group: 'Tests' with: #('Javascript-Tests-Pharo-Core' 'Seaside-Tests-Pharo-Core' 'Seaside-Tests-Pharo-Functional' 'Seaside-Tests-FileSystem' 'Comet-Tests-Core' 'Seaside-Tests-Pharo-Continuation' 'Seaside-Tests-Pharo-Development' 'Seaside-Tests-Adaptors-Comanche' );
				yourself ].

	spec for: #pharo do: [
		spec
			project: 'Grease-Slime' with: [
				spec
					className: 'ConfigurationOfGrease';
					loads: #('Grease-Slime' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease-Tests-Slime' copyFrom: 'Grease-Slime' with: [
				spec loads: #('Grease-Tests-Slime' ) ];
			yourself.
		spec
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease-Slime'). ];
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease-Tests-Slime' ) ];
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Slime'  );
			group: 'Tests' with: #('Seaside-Tests-Slime' );
			yourself. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					loads: #('FastCGI' );
					file: 'ConfigurationOfGsFastCGI';
					repository: 'http://seaside.gemstone.com/ss/fastcgi' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/GemStone' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-Core' 
				with: [ spec file: 'JQuery-Core.gemstone' ];
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Core' 
				with: [ spec file: 'Prototype-Core.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow';
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];

			package: 'JQuery-Tests-Core'
				with: [ spec includes: #('JQuery-Tests-GemStone-Core' ) ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];

			package: 'Seaside-GemStone-Continuation' 
				with: [ spec requires: #('Grease' ) ];
			package: 'Seaside-GemStone-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Grease' 'Seaside-GemStone-Continuation' ) ];

			package: 'JQuery-Tests-GemStone-Core'
				with: [ spec requires: #('JQuery-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' 'Grease Tests' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			yourself.].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 11/18/2010 09:51'!
baseline300alpha511Common: spec 
	<version: '3.0.0-alpha5.11-commonBaseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'fix project versions'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha5-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Tests'
				copyFrom: 'Grease'
				with: [ 
					spec 
						versionString: '1.0-alpha5-baseline';
						loads: #('Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2.0.2-baseline';
					file: 'ConfigurationOfSwazoo2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' ). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Seaside-Swazoo'  
				with: [ 
					spec 
						requires: #('Grease' 'Swazoo2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' ). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself. ].

! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 07/23/2010 10:22'!
baseline300alpha515: spec 
	<version: '3.0.0-alpha5.15-baseline' imports: #( '3.0.0-alpha5.15-commonBaseline' )>

	spec for: #common do: [
		spec
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 
				'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 
				'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web'  
				'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 
				'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 
				'Seaside-Tests-Email' 'Seaside-Tests-Functional'  
				'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 
				'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 
				'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 
				'Seaside-Tests-UTF8' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfKomHttpServer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31-baseline';
					file: 'ConfigurationOfSPort2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Canvas' 
				with: [ spec includes: #('Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ 
				spec 
					requires: #( 'OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core') ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'SPort2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Javascript-Tests-Pharo-Core' 
				with: [ spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];	
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 'Seaside-FileSystem' );
			group: 'Tests' with: #( 'Seaside-Tests-FileSystem' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
				yourself ].

	spec for: #pharo do: [
		spec
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [ 
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ];
			yourself.
		spec
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease Slime'). ];
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ) ];
			yourself. 

		spec
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' );
			yourself. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsCore';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: '0.231-baseline';
					loads: #('FastCGI' );
					file: 'ConfigurationOfGsFastCGI';
					repository: 'http://seaside.gemstone.com/ss/fastcgi' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-Core' 
				with: [ spec file: 'JQuery-Core.gemstone' ];
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Core' 
				with: [ spec file: 'Prototype-Core.gemstone' ];
			package: 'Seaside-Canvas' 
				with: [ spec file: 'Seaside-Canvas.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' 'GsCore' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. 

		spec
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' );
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow';
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Development' with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Environment' 
				with: [ spec requires: #('Seaside-GemStone-Tools-Production') ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];

			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];

			package: 'Seaside-GemStone-Basic-Development';
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Development' with: [
				 spec 
					requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 
								'Seaside-GemStone-Tools-Production' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-GemStone-Continuation' ) ];
			"Ultimately should be in #gemstone ... object log tool shouldn't need continuations"
			package: 'Seaside-GemStone-Tools-Production'
				with: [spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development')];

			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			yourself.].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 11/18/2010 09:51'!
baseline300alpha515Common: spec 
	<version: '3.0.0-alpha5.15-commonBaseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'fix project versions'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease Core' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha9.3-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Core Tests' copyFrom: 'Grease Core' with: [ 
					spec loads: #('Core Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2.0.2-baseline';
					file: 'ConfigurationOfSwazoo2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease Core' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' 'Seaside-Environment'). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets'). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Welcome' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tools-Web' 'Seaside-Examples' 
					  'Seaside-Development' 'JQuery-Core' 'JQuery-UI' 'Seaside-Tests-Flow' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Seaside-Swazoo'  
				with: [ 
					spec 
						requires: #('Grease Core' 'Swazoo2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Core Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Environment'). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself.
		spec
			group: 'Base' with: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 
				'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow'
				 'Seaside-Environment' 'Seaside-Widgets' );
			group: 'Base Tests' with: #('Base' 'Seaside-Tests-Core' 'Seaside-Tests-Canvas'
				'Seaside-Tests-Session' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
				'Seaside-Tests-Environment' 'Seaside-Tests-Flow' );
			group: 'Development' with: #('Base' 'Seaside-Development' );
			group: 'Development Tests' with: #('Development' 'Base Tests' 'Seaside-Tests-Development' );
			yourself. ].

! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 11/5/2010 16:24'!
baseline300rc2: spec 
	<version: '3.0.0-rc.2-baseline' imports: #( '3.0.0-rc.2-commonBaseline' )>

	spec for: #common do: [
		spec blessing: #baseline.
		spec
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 
				'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 
				'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web'  
				'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 
				'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 
				'Seaside-Tests-Email' 'Seaside-Tests-Functional'  
				'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 
				'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 
				'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 
				'Seaside-Tests-UTF8' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfKomHttpServer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31-baseline';
					file: 'ConfigurationOfSPort2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Canvas' 
				with: [ spec includes: #('Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ 
				spec 
					requires: #( 'OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core') ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'SPort2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Javascript-Tests-Pharo-Core' 
				with: [ spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];	
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 'Seaside-FileSystem' );
			group: 'Tests' with: #( 'Seaside-Tests-FileSystem' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 
				'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 
				'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web'  
				'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 
				'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 
				
				 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 
				'Seaside-Tests-Email' 'Seaside-Tests-Functional'  
				'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 
				'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 
				'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 
				'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
				yourself ].

	spec for: #pharo do: [
		spec
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [ 
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ];
			yourself.
		spec
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease Slime'). ];
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ) ];
			yourself. 

		spec
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' );
			yourself. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsCore';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: '0.231-baseline';
					loads: #('FastCGI' );
					file: 'ConfigurationOfGsFastCGI';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Development' with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production') ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Seaside-Canvas' 
				with: [ spec file: 'Seaside-Canvas.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' 'GsCore' ) ];
			package: 'Seaside-GemStone-Development' with: [
				 spec 
					requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 
								'Seaside-GemStone-Tools-Production' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-GemStone-Continuation' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Production'
				with: [spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development')];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. 

		spec
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' );
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone240-Core' ) ];
			package: 'Seaside-GemStone240-Core' with: [ 
				spec 
					includes: #('Seaside-GemStone-Core' );
					requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' with: [ 
				spec requires: #('Seaside-GemStone240-Core' ) ];

			yourself.].
	spec for: #'gs3.x' do: [
		spec
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone300-Core' ) ];
			package: 'Seaside-GemStone300-Core' with: [ 
				spec 
					includes: #('Seaside-GemStone-Core' );
					requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' with: [ 
				spec requires: #('Seaside-GemStone300-Core' ) ];
			yourself.].! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 11/18/2010 09:51'!
baseline300rc2Common: spec 
	<version: '3.0.0-rc.2-commonBaseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'fix project versions'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease Core' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha9.3-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Core Tests' copyFrom: 'Grease Core' with: [ 
					spec loads: #('Core Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2.0.2-baseline';
					file: 'ConfigurationOfSwazoo2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease Core' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' 'Seaside-Environment'). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets'). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Welcome' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tools-Web' 'Seaside-Examples' 
					  'Seaside-Development' 'JQuery-Core' 'JQuery-UI' 'Seaside-Flow' 
					  'Seaside-Tests-Flow'  'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Seaside-Swazoo'  
				with: [ 
					spec 
						requires: #('Grease Core' 'Swazoo2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tests-Core'). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Core Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Environment'). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself.
		spec
			group: 'Base' with: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 
				'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow'
				 'Seaside-Environment' 'Seaside-Widgets' );
			group: 'Base Tests' with: #('Base' 'Seaside-Tests-Core' 'Seaside-Tests-Canvas'
				'Seaside-Tests-Session' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
				'Seaside-Tests-Environment' 'Seaside-Tests-Flow' );
			group: 'Development' with: #('Base' 'Seaside-Development' );
			group: 'Development Tests' with: #('Development' 'Base Tests' 'Seaside-Tests-Development' );
			yourself. ].

! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 11/5/2010 16:24'!
baseline300rc3: spec 
	<version: '3.0.0-rc.3-baseline' imports: #( '3.0.0-rc.2-commonBaseline' )>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: '- ported Seaside-FileSystem to GemStone (GemStone Issue 165)'.
		spec
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			yourself.
		spec
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 
				'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 
				'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web'  
				'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 
				'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 
				'Seaside-Tests-Email' 'Seaside-Tests-Functional'  
				'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 
				'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 
				'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 
				'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfKomHttpServer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31-baseline';
					file: 'ConfigurationOfSPort2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Canvas' 
				with: [ spec includes: #('Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ 
				spec 
					requires: #( 'OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core') ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ spec requires: #('SPort2' ). ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Javascript-Tests-Pharo-Core' 
				with: [ spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];	
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #( 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 
				'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 
				'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web'  
				'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 
				'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 
				
				 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 
				'Seaside-Tests-Email' 'Seaside-Tests-Functional'  
				'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 
				'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 
				'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 
				'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
				yourself ].

	spec for: #pharo do: [
		spec
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [ 
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ];
			yourself.
		spec
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease Slime'). ];
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ) ];
			yourself. 

		spec
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' );
			yourself. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsCore';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: '0.231-baseline';
					loads: #('FastCGI' );
					file: 'ConfigurationOfGsFastCGI';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Development' with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production') ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Seaside-Canvas' 
				with: [ spec file: 'Seaside-Canvas.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' 'GsCore' ) ];
			package: 'Seaside-GemStone-Development' with: [
				 spec 
					requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 
								'Seaside-GemStone-Tools-Production' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-GemStone-Continuation' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Production'
				with: [spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development')];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];

			package: 'Seaside-FileSystem' 
				with: [ spec file:  'Seaside-FileSystem.gemstone'. ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. 

		spec
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' );
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone240-Core' ) ];
			package: 'Seaside-GemStone240-Core' with: [ 
				spec 
					includes: #('Seaside-GemStone-Core' );
					requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' with: [ 
				spec requires: #('Seaside-GemStone240-Core' ) ];

			yourself.].
	spec for: #'gs3.x' do: [
		spec
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone300-Core' ) ];
			package: 'Seaside-GemStone300-Core' with: [ 
				spec 
					includes: #('Seaside-GemStone-Core' );
					requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' with: [ 
				spec requires: #('Seaside-GemStone300-Core' ) ];
			yourself.].! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 11/5/2010 16:24'!
baseline300rc: spec 
	<version: '3.0.0-rc-baseline' imports: #( '3.0.0-rc-commonBaseline' )>

	spec for: #common do: [
		spec blessing: #baseline.
		spec
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 
				'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 
				'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web'  
				'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 
				'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 
				'Seaside-Tests-Email' 'Seaside-Tests-Functional'  
				'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 
				'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 
				'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 
				'Seaside-Tests-UTF8' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfKomHttpServer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31-baseline';
					file: 'ConfigurationOfSPort2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Canvas' 
				with: [ spec includes: #('Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ 
				spec 
					requires: #( 'OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core') ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' 'SPort2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Javascript-Tests-Pharo-Core' 
				with: [ spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];	
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 'Seaside-FileSystem' );
			group: 'Tests' with: #( 'Seaside-Tests-FileSystem' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 
				'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 
				'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web'  
				'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 
				'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 
				
				 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 
				'Seaside-Tests-Email' 'Seaside-Tests-Functional'  
				'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 
				'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 
				'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 
				'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
				yourself ].

	spec for: #pharo do: [
		spec
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [ 
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ];
			yourself.
		spec
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease Slime'). ];
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ) ];
			yourself. 

		spec
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' );
			yourself. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsCore';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: '0.231-baseline';
					loads: #('FastCGI' );
					file: 'ConfigurationOfGsFastCGI';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' ) ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-Core' 
				with: [ spec file: 'JQuery-Core.gemstone' ];
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Core' 
				with: [ spec file: 'Prototype-Core.gemstone' ];
			package: 'Seaside-Canvas' 
				with: [ spec file: 'Seaside-Canvas.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' 'GsCore' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. 

		spec
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' );
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow';
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Development' with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Environment' 
				with: [ spec requires: #('Seaside-GemStone-Tools-Production') ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];

			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];

			package: 'Seaside-GemStone-Basic-Development';
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone240-Core' ) ];
			package: 'Seaside-GemStone240-Core' with: [ 
				spec 
					includes: #('Seaside-GemStone-Core' );
					requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' with: [ 
				spec requires: #('Seaside-GemStone240-Core' ) ];
			package: 'Seaside-GemStone-Development' with: [
				 spec 
					requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 
								'Seaside-GemStone-Tools-Production' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-GemStone-Continuation' ) ];
			"Ultimately should be in #gemstone ... object log tool shouldn't need continuations"
			package: 'Seaside-GemStone-Tools-Production'
				with: [spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development')];

			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			yourself.].
	spec for: #'gs3.x' do: [
		spec
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone300-Core' ) ];
			package: 'Seaside-GemStone300-Core' with: [ 
				spec 
					includes: #('Seaside-GemStone-Core' );
					requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' with: [ 
				spec requires: #('Seaside-GemStone300-Core' ) ];
			yourself.].! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 11/18/2010 09:51'!
baseline300rcCommon: spec 
	<version: '3.0.0-rc-commonBaseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'fix project versions'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease Core' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0-alpha9.3-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGrease';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Core Tests' copyFrom: 'Grease Core' with: [ 
					spec loads: #('Core Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2.0.2-baseline';
					file: 'ConfigurationOfSwazoo2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease Core' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' 'Seaside-Environment'). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets'). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Welcome' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tools-Web' 'Seaside-Examples' 
					  'Seaside-Development' 'JQuery-Core' 'JQuery-UI' 'Seaside-Flow' 
					  'Seaside-Tests-Flow'  'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Seaside-Swazoo'  
				with: [ 
					spec 
						requires: #('Grease Core' 'Swazoo2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' ). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Core Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Environment'). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			yourself.
		spec
			group: 'Base' with: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 
				'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow'
				 'Seaside-Environment' 'Seaside-Widgets' );
			group: 'Base Tests' with: #('Base' 'Seaside-Tests-Core' 'Seaside-Tests-Canvas'
				'Seaside-Tests-Session' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
				'Seaside-Tests-Environment' 'Seaside-Tests-Flow' );
			group: 'Development' with: #('Base' 'Seaside-Development' );
			group: 'Development Tests' with: #('Development' 'Base Tests' 'Seaside-Tests-Development' );
			yourself. ].

! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 11/17/2010 13:18'!
baseline3011: spec
	<version: '3.0.1.1-baseline' imports: #('3.0.1.1-commonBaseline' )>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ].
		spec 
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' 'Seaside-Tests-Welcome' ).].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0.6-baseline';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1.4';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31-baseline';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ). ];
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-Pharo-Tools-Web' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ). ];
			package: 'Comet-Pharo-Core' with: [
				spec requires: #('Comet-Core' ). ];
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-Pharo-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Core' 'Kom' ). ];
			package: 'Comet-Core' with: [
				spec requires: #('Seaside-Canvas' 'Javascript-Core' );
					includes: #('Comet-Pharo-Core' ). ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-UI' 'Comet-Core' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('SPort2' ). ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ). ];
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ). ].
		spec 
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #('Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' ).].

	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ].].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ].
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ).].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.242';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: '0.234';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: '0.239';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('OB' );
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone';
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-GemStone-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' ).].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ].].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ].].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 11/18/2010 09:51'!
baseline3011commonBaseline: spec
	<version: '3.0.1.1-commonBaseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease Core' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0.1.1-baseline';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Core Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Core Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2.0.2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' with: [
				spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' with: [
				spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' with: [
				spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' with: [
				spec requires: #('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' with: [
				spec requires: #('Grease Core' ). ];
			package: 'Seaside-Development' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' 'Seaside-Environment' ). ];
			package: 'Seaside-Email' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' with: [
				spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Welcome' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tools-Web' 'Seaside-Examples' 'Seaside-Development' 'JQuery-Core' 'JQuery-UI' 'Seaside-Flow' 'Seaside-Tests-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			package: 'Seaside-Swazoo' with: [
				spec 
					requires: #('Grease Core' 'Swazoo2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Core' 'Seaside-Swazoo' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' with: [
				spec requires: #('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development' 'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' with: [
				spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' with: [
				spec requires: #('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' with: [
				spec requires: #('RSS-Core' 'Seaside-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Core' with: [
				spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' with: [
				spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' with: [
				spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec requires: #('Seaside-Core' 'Grease Core Tests' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' with: [
				spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tests-HTML5' with: [
				spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' with: [
				spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' with: [
				spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ].
		spec 
			group: 'Base' with: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Environment' 'Seaside-Widgets' );
			group: 'Base Tests' with: #('Base' 'Seaside-Tests-Core' 'Seaside-Tests-Canvas' 'Seaside-Tests-Session' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Flow' );
			group: 'Development' with: #('Base' 'Seaside-Development' );
			group: 'Development Tests' with: #('Development' 'Base Tests' 'Seaside-Tests-Development' ).].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 11/9/2010 15:50'!
baseline301: spec 
	<version: '3.0.1-baseline' imports: #( '3.0.1-commonBaseline' )>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: '- pick up Seaside-Tests-Welcome
- update the project reference versions)'.
		spec
			package: 'Seaside-FileSystem' 
				with: [ 
					spec 
						requires: #('Seaside-Core' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' 
				with: [ spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			yourself.
		spec
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 
				'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 
				'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web'  
				'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 
				'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 
				'Seaside-Tests-Email' 'Seaside-Tests-Functional'  
				'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 
				'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 
				'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 
				'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' 'Seaside-Tests-Welcome');
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0.6-baseline';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1.4';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31-baseline';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
			
		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Canvas' 
				with: [ spec includes: #('Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Development' 
				with: [ spec includes: #('Seaside-Pharo-Development' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-Pharo-Email' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-Pharo-Environment' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-Pharo-Flow' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-Pharo-Tools-Web' ) ];
			package: 'Seaside-Tools-OmniBrowser' with: [ 
				spec 
					requires: #( 'OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			
			package: 'Seaside-Pharo-Canvas' 
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Pharo-Core' 
				with: [ spec requires: #('Comet-Core' ) ];
			package: 'Javascript-Pharo-Core' 
				with: [ spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' 
				with: [ spec requires: #('Seaside-Core') ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow') ];
			package: 'Seaside-Pharo-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Environment' 
				with: [ spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];
			package: 'Seaside-Pharo-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Pharo-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-Pharo-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ) ];

			package: 'Seaside-Adaptors-Comanche'  
				with: [ spec requires: 
					#('Seaside-Core' 'Kom' ) ];
			
			package: 'Comet-Core'  
				with: [ spec 
					includes: #('Comet-Pharo-Core' );
					requires: #('Seaside-Canvas' 'Javascript-Core' ) ];
			package: 'Comet-Examples' 
				with: [ spec requires: #('JQuery-UI' 'Comet-Core' ) ];
			
			package: 'Seaside-FileSystem' 
				with: [ spec requires: #('SPort2' ). ];

			package: 'Comet-Tests-Core'  
				with: [ spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Javascript-Tests-Pharo-Core' 
				with: [ spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation'  
				with: [ spec requires: #('Seaside-Pharo-Continuation' ) ];
			package: 'Seaside-Tests-Pharo-Core'
				with: [ spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];	
			package: 'Seaside-Tests-Pharo-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ) ];
			package: 'Seaside-Tests-Pharo-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ];
			
			package: 'Seaside-Tests-Adaptors-Comanche'  
				with: [ spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' )];	
			yourself. 

		spec
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #( 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 
				'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 
				'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web'  
				'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 
				'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 
				
				 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 
				'Seaside-Tests-Email' 'Seaside-Tests-Functional'  
				'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 
				'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 
				'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 
				'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
				yourself ].

	spec for: #squeak do: [
		spec 
			package: 'Seaside-Welcome' 
				with: [ spec includes: 'Seaside-Squeak-Welcome'.];
			package: 'Seaside-Squeak-Welcome' 
				with: [ spec requires: 'Seaside-Welcome'.];
			yourself. ].
	spec for: #pharo do: [
		spec
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [ 
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ];
			yourself.
		spec
			package: 'Seaside-Welcome' 
				with: [ spec includes: 'Seaside-Pharo-Welcome'.];
			package: 'Seaside-Pharo-Welcome' 
				with: [ spec requires: 'Seaside-Welcome'.];
			package: 'Seaside-Slime' 
				with: [ spec requires: #('Grease Slime'). ];
			package: 'Seaside-Tests-Slime' 
				with: [ spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ) ];
			yourself. 

		spec
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' );
			yourself. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.239-baseline';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: '0.231-baseline';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: '0.239-baseline';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.

		spec
			package: 'Javascript-Core' 
				with: [ spec includes: #('Javascript-GemStone-Core' ) ];
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone-Core' ) ];
			package: 'Seaside-Development' with: [ spec includes: #('Seaside-GemStone-Development' ) ];
			package: 'Seaside-Adaptors-Swazoo' 
				with: [ spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Seaside-Email' 
				with: [ spec includes: #('Seaside-GemStone-Email' ) ];
			package: 'Seaside-Flow' 
				with: [ spec includes: #('Seaside-GemStone-Flow' ) ];
			package: 'Seaside-Environment' 
				with: [ spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production') ];
			package: 'Seaside-Session' 
				with: [ 
					spec 
						file: 'Seaside-Session.gemstone';
						includes: #('Seaside-GemStone-Session' ) ];
			package: 'Seaside-Tools-OmniBrowser'  
				with: [ 
					spec 
						requires: #( 'OB' );
						includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ];
			package: 'Seaside-Tools-Web' 
				with: [ spec includes: #('Seaside-GemStone-Tools-Web' ) ];
			package: 'Seaside-Welcome' 
				with: [ spec includes: 'Seaside-GemStone-Welcome'.];

			package: 'Seaside-Tests-Core' 
				with: [ spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow'). ];
			package: 'Seaside-Tests-Functional'  
				with: [ spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			
			package: 'JQuery-UI' 
				with: [ spec file: 'JQuery-UI.gemstone' ];
			package: 'Javascript-GemStone-Core' 
				with: [ spec requires: #('Javascript-Core' ) ];
			package: 'Seaside-Canvas' 
				with: [ spec file: 'Seaside-Canvas.gemstone' ];
			package: 'Seaside-Core' 
				with: [ spec file: 'Seaside-Core.gemstone' ];
			package: 'Seaside-GemStone-Basic-Development' 
				with: [ spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' 
				with: [ spec requires: #('Seaside-Core' 'GsCore' ) ];
			package: 'Seaside-GemStone-Development' with: [
				 spec 
					requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 
								'Seaside-GemStone-Tools-Production' ) ];
			package: 'Seaside-GemStone-Email' 
				with: [ spec requires: #('Seaside-Email' ) ];
			package: 'Seaside-GemStone-Environment' 
				with: [ spec requires: #('Seaside-Environment' ) ];
			package: 'Seaside-GemStone-Flow'  
				with: [ spec requires: 
					#('Seaside-Flow' 'Seaside-GemStone-Continuation' ) ];
			package: 'Seaside-GemStone-Session' 
				with: [ spec requires: #('Seaside-Session' ) ];
			package: 'Seaside-GemStone-Tools-OmniBrowser'  
				with: [ spec requires: #('Seaside-Tools-OmniBrowser' ) ];
			package: 'Seaside-GemStone-Tools-Production'
				with: [spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development')];
			package: 'Seaside-GemStone-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' ) ];
			package: 'Seaside-GemStone-Welcome' 
				with: [ spec requires: 'Seaside-Welcome'.];
		
			package: 'Seaside-Adaptors-FastCGI'  
				with: [ spec requires: 
					#('Seaside-Core' 'FastCGI' ) ];
			package: 'Seaside-GemStone-Adaptors-Swazoo'  
				with: [ spec requires: 
					#('Seaside-Adaptors-Swazoo' ) ];

			package: 'Seaside-FileSystem' 
				with: [ spec requires:  'GsCore'. ];
			
			package: 'Seaside-Tests-GemStone-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-GemStone-Development'  
				with: [ spec requires: #('Seaside-Tests-Development' ) ];
			package: 'Seaside-Tests-GemStone-Continuation'  
				with: [ spec requires: #('Seaside-GemStone-Continuation' ) ];
			package: 'Seaside-Tests-GemStone-Flow' 
				with: [ spec requires: #('Seaside-Tests-Flow' ) ];
			package: 'Seaside-Tests-GemStone-Functional'  
				with: [ spec requires: #('Seaside-Tests-Functional' ) ];
			yourself. 

		spec
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' );
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone240-Core' ) ];
			package: 'Seaside-GemStone240-Core' with: [ 
				spec 
					includes: #('Seaside-GemStone-Core' );
					requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' with: [ 
				spec requires: #('Seaside-GemStone240-Core' ) ];

			yourself.].
	spec for: #'gs3.x' do: [
		spec
			package: 'Seaside-Core' 
				with: [ spec includes: #('Seaside-GemStone300-Core' ) ];
			package: 'Seaside-GemStone300-Core' with: [ 
				spec 
					includes: #('Seaside-GemStone-Core' );
					requires: #('Seaside-Core' ) ];
			package: 'Seaside-GemStone-Core' with: [ 
				spec requires: #('Seaside-GemStone300-Core' ) ];
			yourself.].! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 11/18/2010 09:51'!
baseline301Common: spec 
	<version: '3.0.1-commonBaseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'pick up Seaside-Tests-Welcom'.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease Core' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0.1-baseline';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Core Tests' copyFrom: 'Grease Core' with: [ 
					spec loads: #('Core Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2.0.2-baseline';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Javascript-Core' 
				with: [ spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' 
				with: [ spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' 
				with: [ spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' 
				with: [ spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' 
				with: [ spec requires: 
					#('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' 
				with: [ spec requires: #('Grease Core' ). ];
			package: 'Seaside-Development' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' 'Seaside-Environment'). ];
			package: 'Seaside-Email' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component'
					  'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets'). ];
			package: 'Seaside-Examples' 
				with: [ spec requires: 
					#('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' 
				with: [ spec requires: 
					#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
					  'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' 
				with: [ spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' 
				with: [ spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' 
				with: [ spec requires:  
							#('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop'
							  'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' 
				with: [ spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' 
				with: [ spec requires: 
					#('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Welcome' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tools-Web' 'Seaside-Examples' 
					  'Seaside-Development' 'JQuery-Core' 'JQuery-UI' 'Seaside-Flow' 
					  'Seaside-Tests-Flow'  'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			
			package: 'Seaside-Swazoo'  
				with: [ 
					spec 
						requires: #('Grease Core' 'Swazoo2' );
						repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo'  
				with: [ spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ];

			package: 'Javascript-Tests-Core' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' 
				with: [ spec requires: 
					#('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development'
					  'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' 
				with: [ spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' 
				with: [ spec requires: 
					#('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' 
				with: [ spec requires: #('RSS-Core' 'Seaside-Tests-Core'). ];
			package: 'Scriptaculous-Tests-Core' 
				with: [ spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' 
				with: [ spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' 
				with: [ spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' 
				with: [ spec requires: #('Seaside-Core' 'Grease Core Tests' ). ];
			package: 'Seaside-Tests-Development' 
				with: [ spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Environment'). ];
			package: 'Seaside-Tests-Email' 
				with: [ spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Tests-Environment' 
				with: [ spec requires: 
					#('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
					  'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' 
				with: [ spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' 
				with: [ spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' 
				with: [  spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tests-HTML5' 
				with: [ spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' 
				with: [ spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' 
				with: [ spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' 
				with: [ spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' 
				with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' 
				with: [ spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Welcome' 
				with: [ spec requires: #('Seaside-Welcome' ). ];
			yourself.
		spec
			group: 'Base' with: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 
				'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow'
				 'Seaside-Environment' 'Seaside-Widgets' );
			group: 'Base Tests' with: #('Base' 'Seaside-Tests-Core' 'Seaside-Tests-Canvas'
				'Seaside-Tests-Session' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop'
				'Seaside-Tests-Environment' 'Seaside-Tests-Flow' );
			group: 'Development' with: #('Base' 'Seaside-Development' );
			group: 'Development Tests' with: #('Development' 'Base Tests' 'Seaside-Tests-Development' );
			yourself. ].

! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'pmm 11/21/2010 12:45'!
baseline302: spec
	<version: '3.0.2-baseline' imports: #('3.0.2-commonBaseline' )>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ].
		spec 
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' 'Seaside-Tests-Welcome' ).].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0.6-baseline';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1.4';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31-baseline';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ). ];
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-Pharo-Tools-Web' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ). ];
			package: 'Comet-Pharo-Core' with: [
				spec requires: #('Comet-Core' ). ];
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-Pharo-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Core' 'Kom' ). ];
			package: 'Comet-Core' with: [
				spec requires: #('Seaside-Canvas' 'Javascript-Core' );
					includes: #('Comet-Pharo-Core' ). ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-UI' 'Comet-Core' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('SPort2' ). ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ). ];
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ). ].
		spec 
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #('Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' ).].

	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ].].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ].
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ).].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.242';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: '0.234';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: '0.239';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('OB' );
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone';
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-GemStone-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' ).].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ].].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ].].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 11/22/2010 10:03'!
baseline302commonBaseline: spec
	<version: '3.0.2-commonBaseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease Core' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0.2-baseline';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Core Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Core Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2.0.2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' with: [
				spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' with: [
				spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' with: [
				spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' with: [
				spec requires: #('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' with: [
				spec requires: #('Grease Core' ). ];
			package: 'Seaside-Development' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' 'Seaside-Environment' ). ];
			package: 'Seaside-Email' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' with: [
				spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Welcome' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tools-Web' 'Seaside-Examples' 'Seaside-Development' 'JQuery-Core' 'JQuery-UI' 'Seaside-Flow' 'Seaside-Tests-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			package: 'Seaside-Swazoo' with: [
				spec 
					requires: #('Grease Core' 'Swazoo2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Core' 'Seaside-Swazoo' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' with: [
				spec requires: #('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development' 'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' with: [
				spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' with: [
				spec requires: #('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' with: [
				spec requires: #('RSS-Core' 'Seaside-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Core' with: [
				spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' with: [
				spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' with: [
				spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec requires: #('Seaside-Core' 'Grease Core Tests' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' with: [
				spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tests-HTML5' with: [
				spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' with: [
				spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' with: [
				spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ].
		spec 
			group: 'Base' with: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Environment' 'Seaside-Widgets' );
			group: 'Base Tests' with: #('Base' 'Seaside-Tests-Core' 'Seaside-Tests-Canvas' 'Seaside-Tests-Session' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Flow' );
			group: 'Development' with: #('Base' 'Seaside-Development' );
			group: 'Development Tests' with: #('Development' 'Base Tests' 'Seaside-Tests-Development' ).].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 12/10/2010 12:05'!
baseline303: spec
	<version: '3.0.3-baseline' imports: #('3.0.3-commonBaseline' )>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ].
		spec 
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' 'Seaside-Tests-Welcome' ).].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: '1.0.6-baseline';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1.4';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31-baseline';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ). ];
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-Pharo-Tools-Web' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ). ];
			package: 'Comet-Pharo-Core' with: [
				spec requires: #('Comet-Core' ). ];
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-Pharo-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Core' 'Kom' ). ];
			package: 'Comet-Core' with: [
				spec requires: #('Seaside-Canvas' 'Javascript-Core' );
					includes: #('Comet-Pharo-Core' ). ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-UI' 'Comet-Core' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('SPort2' ). ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ). ];
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ). ].
		spec 
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #('Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' ).].

	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ].].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ].
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ).].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.242';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: '0.234';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: '0.239';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('OB' );
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone';
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-ServiceTask' with: [
				spec requires: #('Seaside-GemStone-Tools-Production')];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-GemStone-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' ).].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ].].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ].].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 12/10/2010 12:01'!
baseline303commonBaseline: spec
	<version: '3.0.3-commonBaseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease Core' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: '1.0.2-baseline';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Core Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Core Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: '2.2.0.2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' with: [
				spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' with: [
				spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' with: [
				spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' with: [
				spec requires: #('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' with: [
				spec requires: #('Grease Core' ). ];
			package: 'Seaside-Development' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' 'Seaside-Environment' ). ];
			package: 'Seaside-Email' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' with: [
				spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Welcome' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tools-Web' 'Seaside-Examples' 'Seaside-Development' 'JQuery-Core' 'JQuery-UI' 'Seaside-Flow' 'Seaside-Tests-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			package: 'Seaside-Swazoo' with: [
				spec 
					requires: #('Grease Core' 'Swazoo2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Core' 'Seaside-Swazoo' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' with: [
				spec requires: #('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development' 'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' with: [
				spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' with: [
				spec requires: #('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' with: [
				spec requires: #('RSS-Core' 'Seaside-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Core' with: [
				spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' with: [
				spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' with: [
				spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec requires: #('Seaside-Core' 'Grease Core Tests' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' with: [
				spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tests-HTML5' with: [
				spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' with: [
				spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' with: [
				spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ].
		spec 
			group: 'Base' with: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Environment' 'Seaside-Widgets' );
			group: 'Base Tests' with: #('Base' 'Seaside-Tests-Core' 'Seaside-Tests-Canvas' 'Seaside-Tests-Session' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Flow' );
			group: 'Development' with: #('Base' 'Seaside-Development' );
			group: 'Development Tests' with: #('Development' 'Base Tests' 'Seaside-Tests-Development' ).].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 2/28/2011 13:56'!
baseline304: spec
	<version: '3.0.4-baseline' imports: #('3.0.4-baseline-commonBaseline' )>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ].
		spec 
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' 'Seaside-Tests-Welcome' ). ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: #'bleedingEdge';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ). ];
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-Pharo-Tools-Web' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ). ];
			package: 'Comet-Pharo-Core' with: [
				spec requires: #('Comet-Core' ). ];
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-Pharo-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Core' 'Kom' ). ];
			package: 'Comet-Core' with: [
				spec 
					requires: #('Seaside-Canvas' 'Javascript-Core' );
					includes: #('Comet-Pharo-Core' ). ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-UI' 'Comet-Core' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('SPort2' ). ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ). ];
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Email' 'Grease Core Tests'). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ). ].
		spec 
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #('Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' ). ].

	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ]. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ].
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ). ].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: #'stable';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone';
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-ServiceTask' with: [
				spec requires: #('Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-GemStone-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' ). ].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ]. ].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ]. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'DaleHenrichs 02/15/2011 12:03'!
baseline304commonBaseline: spec
	<version: '3.0.4-baseline-commonBaseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease Core' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Core Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Core Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: #'stable';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' with: [
				spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' with: [
				spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' with: [
				spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' with: [
				spec requires: #('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' with: [
				spec 
					postLoadDoIt: #seaside304DoIts;
					requires: #('Grease Core' ). ];
			package: 'Seaside-Development' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' 'Seaside-Environment' ). ];
			package: 'Seaside-Email' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' with: [
				spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Welcome' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tools-Web' 'Seaside-Examples' 'Seaside-Development' 'JQuery-Core' 'JQuery-UI' 'Seaside-Flow' 'Seaside-Tests-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			package: 'Seaside-Swazoo' with: [
				spec 
					requires: #('Grease Core' 'Swazoo2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Core' 'Seaside-Swazoo' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' with: [
				spec requires: #('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development' 'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' with: [
				spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' with: [
				spec requires: #('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' with: [
				spec requires: #('RSS-Core' 'Seaside-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Core' with: [
				spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' with: [
				spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' with: [
				spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec requires: #('Seaside-Core' 'Grease Core Tests' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' with: [
				spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tests-HTML5' with: [
				spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' with: [
				spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' with: [
				spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ].
		spec 
			group: 'Base' with: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Environment' 'Seaside-Widgets' );
			group: 'Base Tests' with: #('Base' 'Seaside-Tests-Core' 'Seaside-Tests-Canvas' 'Seaside-Tests-Session' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Flow' );
			group: 'Development' with: #('Base' 'Seaside-Development' );
			group: 'Development Tests' with: #('Development' 'Base Tests' 'Seaside-Tests-Development' ). ].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 07/29/2011 18:07'!
baseline3051: spec
	<version: '3.0.5.1-baseline' imports: #('3.0.4-baseline-commonBaseline' )>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ].
		spec 
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' 'Seaside-Tests-Welcome' ). ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: #'bleedingEdge';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ). ];
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-Pharo-Tools-Web' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ). ];
			package: 'Comet-Pharo-Core' with: [
				spec requires: #('Comet-Core' ). ];
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-Pharo-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Core' 'Kom' ). ];
			package: 'Comet-Core' with: [
				spec 
					requires: #('Seaside-Canvas' 'Javascript-Core' );
					includes: #('Comet-Pharo-Core' ). ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-UI' 'Comet-Core' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('SPort2' ). ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ). ];
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Email' 'Grease Core Tests'). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ). ].
		spec 
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #('Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' ). ].

	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ]. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ].
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ). ].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: #'stable';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone';
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-Environment' with: 'Seaside-Environment.gemstone';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-ServiceTask' with: [
				spec requires: #('Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-GemStone-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' ). ].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ]. ].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ]. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 3/28/2012 15:23'!
baseline3061: spec
	<version: '3.0.6.1-baseline' imports: #('3.0.6-baseline-commonBaseline' )>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ].
		spec 
			group: 'default' with: #( 'Core' 'Tests');
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' 'Seaside-Tests-Welcome' ). ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: #'bleedingEdge';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ). ];
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-Pharo-Tools-Web' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ). ];
			package: 'Comet-Pharo-Core' with: [
				spec requires: #('Comet-Core' ). ];
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-Pharo-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Core' 'Kom' ). ];
			package: 'Comet-Core' with: [
				spec 
					requires: #('Seaside-Canvas' 'Javascript-Core' );
					includes: #('Comet-Pharo-Core' ). ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-UI' 'Comet-Core' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('SPort2' ). ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ). ];
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Email' 'Grease Core Tests'). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ). ].
		spec 
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #('Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' ). ].

	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ]. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ].
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ). ].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: #'stable';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ). ];
			package: 'Zinc-Seaside' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Zinc' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone';
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-ServiceTask' with: [
				spec requires: #('Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-GemStone-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-GemStone-Adaptors-Zinc' with: [
				spec requires: #('Zinc-Seaside' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' ). ].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ]. ].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ]. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 09/06/2011 16:34'!
baseline306: spec
	<version: '3.0.6-baseline' imports: #('3.0.6-baseline-commonBaseline' )>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ].
		spec 
			group: 'default' with: #( 'Core' 'Tests');
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' 'Seaside-Tests-Welcome' ). ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: #'bleedingEdge';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ). ];
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-Pharo-Tools-Web' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ). ];
			package: 'Comet-Pharo-Core' with: [
				spec requires: #('Comet-Core' ). ];
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-Pharo-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Core' 'Kom' ). ];
			package: 'Comet-Core' with: [
				spec 
					requires: #('Seaside-Canvas' 'Javascript-Core' );
					includes: #('Comet-Pharo-Core' ). ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-UI' 'Comet-Core' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('SPort2' ). ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ). ];
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Email' 'Grease Core Tests'). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ). ].
		spec 
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #('Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' ). ].

	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ]. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ].
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ). ].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: #'stable';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ). ];
			package: 'Zinc-Seaside' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Zinc' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone';
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-ServiceTask' with: [
				spec requires: #('Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-GemStone-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-GemStone-Adaptors-Zinc' with: [
				spec requires: #('Zinc-Seaside' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' ). ].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ]. ].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ]. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 9/1/2011 17:02'!
baseline306commonBaseline: spec
	<version: '3.0.6-baseline-commonBaseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			project: 'Grease Core' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Core Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Core Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: #'stable';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Zinc' with: [
				spec
					className: 'ConfigurationOfZincHTTPComponents';
					versionString: #'stable';
					loads: #('Zinc-HTTP');
					repository: 'http://www.squeaksource.com/ZincHTTPComponents' ].
		spec 
			package: 'Javascript-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'JQuery-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'JQuery-UI' with: [
				spec requires: #('JQuery-Core' ). ];
			package: 'Prototype-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'RSS-Core' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'RSS-Examples' with: [
				spec requires: #('RSS-Core' 'Seaside-Tools-Core' ). ];
			package: 'Scriptaculous-Core' with: [
				spec requires: #('Prototype-Core' ). ];
			package: 'Scriptaculous-Components' with: [
				spec requires: #('Scriptaculous-Core' 'Seaside-Component' 'Seaside-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Canvas' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' with: [
				spec 
					postLoadDoIt: #seaside304DoIts;
					requires: #('Grease Core' ). ];
			package: 'Seaside-Development' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' 'Seaside-Environment' ). ];
			package: 'Seaside-Email' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' with: [
				spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Welcome' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tools-Web' 'Seaside-Examples' 'Seaside-Development' 'JQuery-Core' 'JQuery-UI' 'Seaside-Flow' 'Seaside-Tests-Flow' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			package: 'Seaside-Swazoo' with: [
				spec 
					requires: #('Grease Core' 'Swazoo2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Zinc-Seaside' with: [
				spec 
					requires: #('Seaside-Core' 'Zinc' );
					repository: 'http://www.squeaksource.com/ZincHTTPComponents'. ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Core' 'Seaside-Swazoo' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec requires: #('Seaside-Tests-Core' 'Javascript-Core' ). ];
			package: 'JQuery-Tests-Core' with: [
				spec requires: #('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development' 'Seaside-Tests-Functional' ). ];
			package: 'JQuery-Tests-UI' with: [
				spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ). ];
			package: 'Prototype-Tests-Core' with: [
				spec requires: #('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional' ). ];
			package: 'RSS-Tests-Core' with: [
				spec requires: #('RSS-Core' 'Seaside-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Core' with: [
				spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core' ). ];
			package: 'Scriptaculous-Tests-Components' with: [
				spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core' ). ];
			package: 'Seaside-Tests-Canvas' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' with: [
				spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec requires: #('Seaside-Core' 'Grease Core Tests' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' with: [
				spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tests-HTML5' with: [
				spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' with: [
				spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' with: [
				spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ].
		spec 
			group: 'Base' with: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Environment' 'Seaside-Widgets' );
			group: 'Base Tests' with: #('Base' 'Seaside-Tests-Core' 'Seaside-Tests-Canvas' 'Seaside-Tests-Session' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Flow' );
			group: 'Development' with: #('Base' 'Seaside-Development' );
			group: 'Development Tests' with: #('Development' 'Base Tests' 'Seaside-Tests-Development' ). ].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 05/24/2012 09:33'!
baseline3071: spec
	<version: '3.0.7.1-baseline' imports: #('3.0.6-baseline-commonBaseline' )>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ].
		spec 
			group: 'default' with: #( 'Core' 'Tests');
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' 'Seaside-Tests-Welcome' ). ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: #'bleedingEdge';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ). ];
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-Pharo-Tools-Web' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Email' with: [
				spec includes: #('Seaside-Tests-Pharo-Email' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ). ];
			package: 'Comet-Pharo-Core' with: [
				spec requires: #('Comet-Core' ). ];
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-Pharo-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Core' 'Kom' ). ];
			package: 'Comet-Core' with: [
				spec 
					requires: #('Seaside-Canvas' 'Javascript-Core' );
					includes: #('Comet-Pharo-Core' ). ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-UI' 'Comet-Core' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('SPort2' ). ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ). ];
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Email' 'Grease Core Tests'). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ). ].
		spec 
			group: 'Core' with: #( 'Zinc-Seaside' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #('Comet-Tests-Core' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Zinc-Seaside' 'Comet-Core' 'Comet-Examples' 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Comet-Tests-Core' ). ].

	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ]. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ].
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ). ].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: #'stable';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ). ];
			package: 'Zinc-Seaside' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Zinc' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone';
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-ServiceTask' with: [
				spec requires: #('Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-GemStone-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-GemStone-Adaptors-Zinc' with: [
				spec requires: #('Zinc-Seaside' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' 'Seaside-Adaptors-Swazoo'). ].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ]. ].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ]. ].
	spec for: #'gs3.1.x' do: [
		spec 
			package: 'Seaside-GemStone-Flow' with: [
				spec file: #('Seaside-GemStone-Flow.310' ). ]]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'dkh 3/28/2012 15:23'!
baseline307: spec
	<version: '3.0.7-baseline' imports: #('3.0.6-baseline-commonBaseline' )>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ].
		spec 
			group: 'default' with: #( 'Core' 'Tests');
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' 'Seaside-Tests-Welcome' ). ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: #'bleedingEdge';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ). ];
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-Pharo-Tools-Web' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Email' with: [
				spec includes: #('Seaside-Tests-Pharo-Email' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ). ];
			package: 'Comet-Pharo-Core' with: [
				spec requires: #('Comet-Core' ). ];
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-Pharo-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Core' 'Kom' ). ];
			package: 'Comet-Core' with: [
				spec 
					requires: #('Seaside-Canvas' 'Javascript-Core' );
					includes: #('Comet-Pharo-Core' ). ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-UI' 'Comet-Core' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('SPort2' ). ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ). ];
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Email' 'Grease Core Tests'). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ). ].
		spec 
			group: 'Core' with: #( 'Zinc-Seaside' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #('Comet-Tests-Core' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Zinc-Seaside' 'Comet-Core' 'Comet-Examples' 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Comet-Tests-Core' ). ].

	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ]. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ].
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ). ].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: #'stable';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ). ];
			package: 'Zinc-Seaside' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Zinc' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone';
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-ServiceTask' with: [
				spec requires: #('Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-GemStone-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-GemStone-Adaptors-Zinc' with: [
				spec requires: #('Zinc-Seaside' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' 'Seaside-Adaptors-Swazoo'). ].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ]. ].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ]. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines' stamp: 'JohanBrichau 3/31/2013 18:48'!
baseline308: spec
	<version: '3.0.8-baseline' imports: #('3.0.6-baseline-commonBaseline' )>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ].
		spec 
			group: 'default' with: #( 'Core' 'Tests');
			group: 'Core' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem' 'Seaside-Tests-Welcome' ). ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: #'bleedingEdge';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.33';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ). ];
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-Pharo-Tools-Web' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ). ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Email' with: [
				spec includes: #('Seaside-Tests-Pharo-Email' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ). ];
			package: 'Comet-Pharo-Core' with: [
				spec requires: #('Comet-Core' ). ];
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-Pharo-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Core' 'Kom' ). ];
			package: 'Comet-Core' with: [
				spec 
					requires: #('Seaside-Canvas' 'Javascript-Core' );
					includes: #('Comet-Pharo-Core' ). ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-UI' 'Comet-Core' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('SPort2' ). ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ). ];
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Pharo-Core' 'Javascript-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Email' 'Grease Core Tests'). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ). ].
		spec 
			group: 'Core' with: #( 'Zinc-Seaside' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #('Comet-Tests-Core' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Zinc-Seaside' 'Comet-Core' 'Comet-Examples' 'Base Tests' 'Development Tests' 'RSS-Tests-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Email' 'Seaside-Tests-Functional' 'Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components' 'JQuery-Tests-Core' 'JQuery-Tests-UI' 'Seaside-Tests-HTML5' 'Seaside-Tests-InternetExplorer' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Comet-Tests-Core' ). ].

	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ]. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ].
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ). ].
		
	spec for: #'pharo2.x' do:[

		spec 
			removeProject: 'OB';
			removeProject: 'Swazoo2'.		

		spec group: 'Core' overrides: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'Prototype-Core' 'Scriptaculous-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-InternetExplorer' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Scriptaculous-Components' 'Seaside-Welcome' 'Seaside-FileSystem' )
	].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: #'stable';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ). ];
			package: 'Zinc-Seaside' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Zinc' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone';
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-ServiceTask' with: [
				spec requires: #('Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-GemStone-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-GemStone-Adaptors-Zinc' with: [
				spec requires: #('Zinc-Seaside' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' 'Seaside-Adaptors-Swazoo'). ].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ]. ].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ]. ].
	spec for: #'gs3.1.x' do: [
		spec 
			package: 'Seaside-GemStone-Flow' with: [
				spec file: #('Seaside-GemStone-Flow.310' ). ]]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'KenTreis 01/24/2013 11:26'!
baseline310adaptors: spec
	<version: '3.1.0-adaptors-baseline' imports: #('3.1.0-pharo-baseline')>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		
		spec project: 'Swazoo2' with: [
			spec
				versionString: #stable;
				className: 'ConfigurationOfSwazoo2';
				loads: #( 'Swazoo');
				repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec project: 'Zinc Project' with: [
			spec
				versionString: #stable;
				className: 'ConfigurationOfZincHTTPComponents';
				loads: #( 'Zinc-HTTP');
				repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec project: 'Grease' with: [
			spec
				versionString: #stable;
				className: 'ConfigurationOfGrease';
				loads: #( 'Grease-Core');
				repository: 'http://www.squeaksource.com/Seaside31' ].
		
		spec package: 'Zinc-Seaside' with: [
			spec
				repository: 'http://www.squeaksource.com/ZincHTTPComponents';
				requires: #('Zinc Project' 'Seaside-Core') ].
		spec
			package: 'Seaside-Swazoo' with: [
				spec 
					requires: #('Grease' 'Swazoo2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Core' 'Seaside-Swazoo' ) ].
	
		spec
			group: 'Swazoo' with: #('Seaside-Adaptors-Swazoo' );
			group: 'Zinc' with: #('Zinc-Seaside') ].
		
	spec for: #'pharo' do: [
		spec
			package: 'Seaside-Adaptors-Comanche' with: [
				spec
					requires: #('KomHttpServerLight' 'Seaside-Core') ];
			package: 'KomHttpServerLight' with: [
				spec
					repository: 'http://www.squeaksource.com/KomHttpServer'];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ) ].
		spec
			group: 'Kom' with: #('Seaside-Adaptors-Comanche' );
			group: 'Comanche' with: #('Seaside-Adaptors-Comanche' )].
		
	spec for: #'squeak' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		
		spec package: 'WebClient-Seaside' with: [
			spec
				repository: 'http://www.squeaksource.com/WebClient';
				requires: #('WebClient-Core' 'Seaside-Core') ].
			
		spec
			package: 'WebClient-Seaside' with: [ spec requires: 'WebClient' ].
		spec
			group: 'WebClient' with: #('WebClient-Seaside' ) ].
		
	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec project: 'FastCGI Project' with: [
			spec
				versionString: #stable;
				className: 'ConfigurationOfFastCGI';
				loads: #( 'FastCGI');
				repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ) ];
			package: 'Zinc-Seaside' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Zinc' ) ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI Project' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-GemStone-Adaptors-Zinc' with: [
				spec requires: #('Zinc-Seaside' ) ].
	
		spec
			group: 'FastCGI' with: #('Seaside-Adaptors-FastCGI' ) ]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'pmm 8/29/2012 14:02'!
baseline310comet: spec
	<version: '3.1.0-comet-baseline' imports: #('3.1.0-jquery-baseline')>

	spec for: #'common' do: [
		spec blessing: #baseline.
		spec 
			package: 'Comet-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-Core' 'Comet-Core'). ].
		spec 
			group: 'Comet' with: #('Comet-Core');
			group: 'Comet Tests' with: #('Comet-Tests-Core' );
			group: 'Comet Examples' with: #('Comet-Examples' ) ].
		
	spec for: #'pharo' do: [
		spec 
			package: 'Comet-Core' with: [
				spec includes: #('Comet-Pharo-Core' ) ];
			package: 'Comet-Pharo-Core' with: [
				spec requires: #('Comet-Core' ) ] ]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'pmm 9/1/2012 10:56'!
baseline310common: spec
	<version: '3.1.0-common-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec project: 'Grease' with: [
			spec
				versionString: #stable;
				className: 'ConfigurationOfGrease';
				loads: #( 'Grease-Core');
				repository: 'http://www.squeaksource.com/Seaside31' ].
		spec
			project: 'Grease Core Tests' copyFrom: 'Grease' with: [
				spec loads: #('Grease-Tests-Core') ].
		spec
			package: 'Seaside-Canvas' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' with: [
				spec requires: #('Grease' ). ];
			package: 'Seaside-Development' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Flow'). ];
			package: 'Seaside-Email' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' with: [
				spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Session' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Canvas' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' with: [
				spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec requires: #('Seaside-Core' 'Grease Core Tests' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' with: [
				spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tests-HTML5' with: [
				spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' with: [
				spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' with: [
				spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' with: [
				spec requires: #('Seaside-Tests-Core' ) ].
		spec 
			group: 'Core' with: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Environment' 'Seaside-Widgets' );
			group: 'Tests' with: #('Core' 'Seaside-Tests-Core' 'Seaside-Tests-Canvas' 'Seaside-Tests-Session' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Flow' );
			group: 'Development' with: #('Core' 'Seaside-Development' );
			group: 'Development Tests' with: #('Development' 'Core' 'Seaside-Tests-Development' );
			group: 'Examples' with: #('Core' 'Seaside-Examples' ) ]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'dkh 9/10/2012 14:45'!
baseline310filesystem: spec
	<version: '3.1.0-filesystem-baseline' imports: #('3.1.0-common-baseline')>

	spec for: #'common' do: [
		spec blessing: #baseline.
		spec project: 'SPort2' with: [
			spec
				versionString: '2.31';
				className: 'ConfigurationOfSPort2';
				loads: #('Sport');
				repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' 'SPort2');
					repository: 'http://www.squeaksource.com/Seaside30LGPL' ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem');
					repository: 'http://www.squeaksource.com/Seaside30LGPL' ].
				
		spec
			group: 'Filesystem' with: #('Seaside-FileSystem' );
			group: 'Filesystem Tests' with: #('Seaside-Tests-FileSystem') ].
	
	spec for: #'gemstone' do: [
		
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable'].
		spec
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ) ] ]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'pmm 8/27/2012 14:17'!
baseline310gemstone: spec
	<version: '3.1.0-gemstone-baseline'>
	
	spec for: #'gemstone' do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-ServiceTask' with: [
				spec requires: #('Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Development' with: #('Seaside-GemStone-Basic-Development');
			group: 'Production' with: #('Seaside-GemStone-Tools-Production') ].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ]. ].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ]. ]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'pmm 8/31/2012 10:42'!
baseline310javascript: spec
	<version: '3.1.0-javascript-baseline' imports: #('3.1.0-common-baseline' '3.1.0-pharo-baseline')>

	spec for: #'common' do: [
		spec blessing: #baseline.
		spec 
			package: 'Javascript-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' ) ];
			package: 'Javascript-Tests-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Tests-Core' ) ].
		spec 
			group: 'Javascript' with: #('Javascript-Core');
			group: 'Javascript Tests' with: #('Javascript-Tests-Core' ) ].
		
	spec for: #'pharo1.x' do: [
		spec 
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ].
		spec 
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Javascript-Pharo-Core' ) ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ) ] ].
		
	spec for: #'pharo2.x' do: [
		spec 
			package: 'Javascript-Pharo20-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ].
		spec 
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Javascript-Pharo20-Core' ) ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo20-Core' ) ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ) ] ].
		
	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ) ] ]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'pmm 8/28/2012 11:03'!
baseline310jquery: spec
	<version: '3.1.0-jquery-baseline' imports: #('3.1.0-json-baseline' '3.1.0-javascript-baseline')>

	spec for: #'common' do: [
		spec blessing: #baseline.
		spec 
			package: 'JQuery-Core' with: [
				spec requires: #('Javascript-Core' ) ];
			package: 'JQuery-Tests-Core' with: [
				spec requires: #('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development' 'Seaside-Tests-Functional') ];
			package: 'JQuery-JSON' with: [
				spec requires: #('JQuery-Core' 'Seaside-JSON-Core') ];
			package: 'JQuery-Tests-JSON' with: [
				spec requires: #('JQuery-JSON' 'JQuery-Tests-Core') ].
		
		spec 
			group: 'JQuery' with: #('JQuery-Core' 'JQuery-JSON');
			group: 'JQuery Tests' with: #('JQuery-Tests-Core' 'JQuery-Tests-JSON') ]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'pmm 8/28/2012 11:04'!
baseline310jqueryui: spec
	<version: '3.1.0-jqueryui-baseline' imports: #('3.1.0-jquery-baseline')>

	spec for: #'common' do: [
		spec blessing: #baseline.
		spec 
			package: 'JQuery-UI' with: [
				spec requires: #('JQuery-Core' ) ];
			package: 'JQuery-Tests-UI' with: [
				spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ) ].
		spec 
			group: 'JQueryUI' with: #('JQuery-UI');
			group: 'JQueryUI Tests' with: #('JQuery-Tests-UI' );
			group: 'JQueryUI Examples' with: #('JQuery-Tests-UI' ) ].
		
	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone' ].! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'pmm 8/28/2012 10:55'!
baseline310json: spec
	<version: '3.1.0-json-baseline' imports: #('3.1.0-common-baseline')>

	spec for: #'common' do: [
		spec blessing: #baseline.
		spec 
			package: 'Seaside-JSON-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' ) ];
			package: 'Seaside-Tests-JSON' with: [
				spec requires: #('Seaside-JSON-Core' ) ].
		spec 
			group: 'JSON' with: #('Seaside-JSON-Core');
			group: 'JSON Tests' with: #('Seaside-Tests-JSON' ) ].
		
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Seaside-JSON-Core' with: [
				spec includes: #('Seaside-Pharo-JSON-Core' ) ].
		spec 
			package: 'Seaside-Pharo-JSON-Core' with: [
				spec requires: #('Seaside-JSON-Core') ] ]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'dkh 9/10/2012 14:44'!
baseline310ob: spec
    <version: '3.1.0-ob-baseline' imports: #('3.1.0-common-baseline')>
    spec
        for: #'squeakCommon'
        do: [ 
            spec blessing: #'baseline'.
            spec
                project: 'OB'
                with: [ 
                    spec
                        className: 'ConfigurationOfOmniBrowser';
                        versionString: #'stable';
                        loads: #('Core');
                        repository: 'http://www.squeaksource.com/MetacelloRepository' ].
            spec package: 'Seaside-Pharo-Tools-OmniBrowser' with: [ spec requires: #('Seaside-Tools-OmniBrowser') ].
            spec
                package: 'Seaside-Tools-OmniBrowser'
                with: [ 
                    spec
                        requires: #('OB' 'Seaside-Tools-Core');
                        includes: #('Seaside-Pharo-Tools-OmniBrowser') ].
            spec group: 'OmniBrowser' with: #('Seaside-Tools-OmniBrowser') ].
    spec
        for: #'pharo1.3.x'
        do: [ 
            spec
                project: 'OB'
                with: [ 
                    spec
                        className: 'ConfigurationOfOmniBrowserLukas';
                        versionString: #'stable';
                        loads: #('default');
                        repository: 'http://www.squeaksource.com/MetacelloRepository' ] ].

	spec for: #'gemstone' do: [
		spec blessing: #baseline.
		spec
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' 'Seaside-Tools-Core');
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ) ].
		spec
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser') ].
		spec 
			 group: 'OmniBrowser' with: #('Seaside-Tools-OmniBrowser') ]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'dkh 9/10/2012 14:43'!
baseline310pharo: spec
	<version: '3.1.0-pharo-baseline' imports: #('3.1.0-common-baseline')>

	
	spec for: #'squeakCommon' do: [
		spec blessing: #baseline.
		spec
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Email' 'Grease Core Tests'). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ) ] ].
				
    spec
        for: #(#'squeak' #'pharo1.x')
        do: [ 
            spec
                package: 'Seaside-Tools-Web' with: [ spec includes: (Array with: 'Seaside-Pharo-Tools-Web') ];
                package: 'Seaside-Pharo-Development'
                    with: [ spec requires: (Array with: 'Seaside-Development' with: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Flow') ];
                package: 'Seaside-Pharo-Tools-Web'
                    with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Core' 'Seaside-Canvas') ].
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ) ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ) ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ) ] ].

	spec for: #'pharo1.x' do: [
			
		spec 
			project: 'Grease Slime' copyFrom: 'Grease' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease' with: [
				spec loads: #('Slime Tests' ) ].
		spec
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ) ].

	spec for: #'pharo2.x' do: [
            spec
                package: 'Seaside-Tools-Web' with: [ spec includes: (Array with: 'Seaside-Pharo20-Tools-Web') ];
                package: 'Seaside-Pharo-Development'
                    with: [ spec requires: (Array with: 'Seaside-Development' with: 'Seaside-Pharo20-Tools-Web' with: 'Seaside-Pharo-Flow') ];
                package: 'Seaside-Pharo20-Tools-Web'
                    with: [ spec requires: #('Seaside-Tools-Web' 'Seaside-Core' 'Seaside-Canvas') ].
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo20-Core' ) ];
			package: 'Seaside-Pharo20-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo20-Core' ) ];
			package: 'Seaside-Tests-Pharo20-Core' with: [
				spec requires: #('Seaside-Pharo20-Core' 'Seaside-Tests-Core' ) ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo20-Core' ) ] ]
! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'pmm 8/28/2012 11:20'!
baseline310rss: spec
	<version: '3.1.0-rss-baseline' imports: #('3.1.0-common-baseline')>

	spec for: #'common' do: [	
		spec blessing: #baseline.
		spec 
			package: 'RSS-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas') ];
			package: 'RSS-Tests-Core' with: [
				spec requires: #('RSS-Core' 'Seaside-Tests-Core') ];
			package: 'RSS-Examples' with: [
				spec requires: #('RSS-Core' 'Seaside-Tools-Core'). ].
		spec 
			group: 'RSS' with: #('RSS-Core');
			group: 'RSS Tests' with: #('RSS-Tests-Core');
			group: 'RSS Examples' with: #('RSS-Examples') ].! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'pmm 8/28/2012 11:22'!
baseline310scriptaculous: spec
	<version: '3.1.0-scriptaculous-baseline' imports: #('3.1.0-javascript-baseline')>

	spec for: #'common' do: [
		spec blessing: #baseline.
		spec 
			package: 'Prototype-Core' with: [
				spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Tests-Core' with: [
				spec requires: #('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional') ];
			package: 'Scriptaculous-Core' with: [
				spec requires: #('Prototype-Core') ];
			package: 'Scriptaculous-Tests-Core' with: [
				spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core') ];
			package: 'Scriptaculous-Components' with: [
				spec requires: #('Scriptaculous-Core' 'Seaside-Flow' 'Seaside-Widgets' 'Seaside-Component') ];
			package: 'Scriptaculous-Tests-Components' with: [
				spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core') ].
		spec 
			group: 'Scriptaculous' with: #('Scriptaculous-Core' 'Scriptaculous-Components');
			group: 'Scriptaculous Tests' with: #('Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components') ]! !

!ConfigurationOfSeaside30 methodsFor: 'baselines-31' stamp: 'pmm 9/1/2012 10:00'!
baseline310welcome: spec
	<version: '3.1.0-welcome-baseline' imports: #('3.1.0-common-baseline' '3.1.0-adaptors-baseline' '3.1.0-rss-baseline' '3.1.0-jqueryui-baseline' '3.1.0-ob-baseline' '3.1.0-comet-baseline')>

	spec for: #'common' do: [
		spec blessing: #baseline.
		spec 
			package: 'Seaside-Welcome' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tools-Web' 'Seaside-Widgets' 'Seaside-Examples' 'Seaside-Development' 'Seaside-Flow' 'Seaside-Tests-Flow' 'JQuery-Core' 'JQuery-UI') ];
			package: 'Seaside-Tests-Welcome' with: [
				spec requires: #('Seaside-Welcome' ) ].
		spec 
			group: 'Welcome' with: #('Seaside-Welcome');
			group: 'Welcome Tests' with: #('Seaside-Tests-Welcome') ].		
	
	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ]. ].
		
	spec for: #'pharo' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ) ].
		"spec
			group: 'OneClick' with: #('Core' 'Development' 'Welcome' 'RSS Examples' 'Comet Examples' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-Examples' 'Seaside-Tools-Web' 'Seaside-Tools-OmniBrowser' 'Kom')"
		spec
			group: 'OneClick' with: #('Core' 'Development' 'Welcome' 'RSS-Examples' 'Comet-Examples' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-Examples' 'Seaside-Tools-Web' 'Seaside-Tools-OmniBrowser' 'Kom') ].
		
	spec for: #'gemstone' do: [
		spec
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ) ] ]! !

!ConfigurationOfSeaside30 methodsFor: 'symbolic versions' stamp: 'JohanBrichau 3/31/2013 18:48'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.0.8-baseline'.
! !

!ConfigurationOfSeaside30 methodsFor: 'symbolic versions' stamp: 'NickAger 4/2/2012 06:33'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfSeaside30 methodsFor: 'accessing' stamp: 'dkh 1/11/2010 14:57'!
project

	^ project ifNil: [ | projectAttributes |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := (Smalltalk at: #MetacelloMCProject) new.
		projectAttributes := #().
		projectAttributes := projectAttributes, ((Smalltalk at: #OBNode ifAbsent: []) == nil
			ifTrue: [ #( #'OBNotPresent' ) ]
			ifFalse: [ #( #'OBPresent' ) ]).
		projectAttributes := projectAttributes, ((Smalltalk at: #ParseTreeEnvironment ifAbsent: []) == nil
			ifTrue: [ #( #'RBNotPresent' ) ]
			ifFalse: [ #( #'RBPresent' ) ]).
		project projectAttributes:  projectAttributes.
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear ]! !

!ConfigurationOfSeaside30 methodsFor: 'doits' stamp: 'DaleHenrichs 02/16/2011 10:27'!
seaside304DoIts
	"see Issue 643: http://code.google.com/p/seaside/issues/detail?id=643"
	
	true ifTrue: [ ^self ].
	"When issue 643 is resolved we'll see what is really needed"
	(Smalltalk at: #WASystemConfiguration) allSubclasses do: [ :each | 
		each instance perform: #clearSearchContexts.
		each instance perform: #clearDescription ].
	"Needed for GemStone ... not clear why yet...."
	(Smalltalk at: #WAFileHandler) default: nil.
	(Smalltalk at: #WASharedConfiguration) initialize.
! !

!ConfigurationOfSeaside30 methodsFor: 'symbolic versions' stamp: 'NickAger 4/2/2012 06:33'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '3.0.7'.
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 10/11/2010 14:46'!
version300: spec
	<version: '3.0.0' imports: #('3.0.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '3.0.0 final'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '10/11/2010 14:22:02'.
		spec 
			project: 'Grease Core' with: '1.0';
			project: 'Grease Core Tests' with: '1.0';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.88';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.107';
			package: 'JQuery-UI' with: 'JQuery-UI-obi.63';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.22';
			package: 'RSS-Core' with: 'RSS-Core-pmm.62';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.100';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.85';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.660';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.139';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.71';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.19';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.22';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.11';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.134';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.17';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-obi.92';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-lr.30';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.58';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.123';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.78';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.12';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.27';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.51';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.198';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.9';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.24';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.28';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.124';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.42';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.6';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.21';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.63';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.9';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.43';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.22';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.14';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-DaleHenrichs.13';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0';
			project: 'Grease Slime Tests' with: '1.0'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.239'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.3';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.65';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.23';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.101';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem.gemstone-DaleHenrichs.24';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-DaleHenrichs.24';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.60';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.21';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.6';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.6';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-DaleHenrichs.8';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.3';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.135';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.10';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.14';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.2';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.661';
			package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'.].
	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.653';
			package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 11/13/2009 10:36'!
version300alpha500: spec
	<version: '3.0.0-alpha5' imports: #('3.0.0-alpha5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'alpha'.
		spec author: 'dkh'.
		spec timestamp: '11/13/2009 10:36'.
		spec 
			project: 'Grease' with: '1.0-alpha1';
			project: 'Grease Tests' with: '1.0-alpha1';
			yourself.
		spec
			package: 'Javascript-Core' with: 'Javascript-Core-jf.65';
			package: 'JQuery-Core' with: 'JQuery-Core-jf.87';
			package: 'JQuery-UI' with: 'JQuery-UI-jf.39';
			package: 'Prototype-Core' with: 'Prototype-Core-jf.12';
			package: 'RSS-Core' with: 'RSS-Core-jf.56';
			package: 'RSS-Examples' with: 'RSS-Examples-jf.19';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-jf.93';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-jf.91';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-jf.72';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.79';
			package: 'Seaside-Core' with: 'Seaside-Core-jf.579';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.120';
			package: 'Seaside-Email' with: 'Seaside-Email-jf.11';
			package: 'Seaside-Environment' with: 'Seaside-Environment-jf.61';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jf.15';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.16';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-jf.7';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-jf.5';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.68';
			package: 'Seaside-Session' with: 'Seaside-Session-jf.122';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.12';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-jf.5';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.11';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-obi.49';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-jf.45';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-jf.90';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-jf.54';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-jf.5';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jf.21';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-jf.38';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-jf.26';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-jf.37';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.26';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-mls.160';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-jf.32';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-jf.6';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-jf.18';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-jf.5';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.20';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-jf.90';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-jf.14';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-jf.8';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-jf.9';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.32';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-jf.9';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-jf.5'.].
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Comet-Core' with: 'Comet-Core-jf.42';
			package: 'Comet-Examples' with: 'Comet-Examples-jf.14';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-jf.3';
			package: 'DynamicBindings' with: 'DynamicBindings-damiencassou.9';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-jf.2';
			package: 'KomServices' with: 'KomServices-gc.19';
			package: 'KomHttpServer' with: 'KomHttpServer-damiencassou.47';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-jf.50';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-obi.28';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-obi.19';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-jf.3';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-jf.3';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-jf.20';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-jf.3';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-jf.4';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-jf.3';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-jf.3';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-jf.6';
			package: 'Seaside-Slime' with: 'Seaside-Slime-jf.56';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.15';
			package: 'Sport-2' with: 'Sport-2.031';
			package: 'Swazoo-2' with: 'Swazoo-2.2';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-jf.7';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-obi.11';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-jf.11';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-jf.3';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-jf.3';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-jf.3';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-jf.5';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-jf.29'.].
	spec for: #'gemstone' do: [
		spec blessing: #'development'.
		spec 
			project: 'FastCGI' with: '0.233';
			yourself.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.88';
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.42';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.7';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.36';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.18';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.6';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.2';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.1';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.5';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.2';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.8';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.8';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.2';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.6';
			package: 'Seaside-Tests-GemStone-UTF8' with: 'Seaside-Tests-GemStone-UTF8-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 12/01/2009 11:22'!
version300alpha501: spec
	<version: '3.0.0-alpha5.1' imports: #('3.0.0-alpha5.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'alpha'.
		spec description: '- based on latest pharo/squeak/gemstone packages in repository as of 11/17/2009 15:10
- eliminate use of #ifNotNil: in a couple of places
- merge JQuery-UI-lr.42 (GemStone)
- merge JQuery-Core-lr.88 (GemStone)
- fix Issue 478: http://code.google.com/p/seaside/issues/detail?id=478 WASimpleNavigation intolerant
- fix Issue 480: http://code.google.com/p/seaside/issues/detail?id=480 WAUploadFunctionalTest fails
- fix Issue 488: http://code.google.com/p/seaside/issues/detail?id=488 Grease tests
- fix Issue 491: http://code.google.com/p/seaside/issues/detail?id=491 WASession>>respond:
- fix Issue 492: http://code.google.com/p/seaside/issues/detail?id=492 SUAllTests>>renderChildrenOn:
- fix Issue 494: http://code.google.com/p/seaside/issues/detail?id=494 WAHtmlDocument>>addLoadScriptFirst:
- fix Issue 496: http://code.google.com/p/seaside/issues/detail?id=496 WAFileHandler default initialization
- fix Issue 498: http://code.google.com/p/seaside/issues/detail?id=498 WAProfilerItem broken
  - work around for http://code.google.com/p/pharo/issues/detail?id=1484 (Pharo)
  - split leaves into sends and time
- fix Issue 499: http://code.google.com/p/seaside/issues/detail?id=499 GRPlatform>>deliverMailFrom:to:text:
- fix Issue 501: http://code.google.com/p/seaside/issues/detail?id=501 WADeprecatedToolFilter not working
- fix Issue 506: http://code.google.com/p/seaside/issues/detail?id=506 WATask and #identityHash
- start development of Seaside-GemStone-Basic-Development that does not require partial continuations and Flow (GemStone)
- fix multi-value field bug in Seaside-Adaptors-FastCGI (GemStone)
- rename WAOldPathComptibilityRequestHandler, which had a typo in it, to something shorter and add a description (Seaside-Environment)
- clarify nomenclature around request handlers a bit
- tool to allow relatively safe use of #allInstances for GemStone (in functional tests at least)
- improve selection handling for config editor
- add simple transaction model to FastCGI adaptor for GemStone
'.
		spec author: 'dkh'.
		spec timestamp: '12/01/09 11:22:13'.
		spec 
			project: 'Grease' with: '1.0-alpha2';
			project: 'Grease Tests' with: '1.0-alpha2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-dkh.67';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.88';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.42';
			package: 'Prototype-Core' with: 'Prototype-Core-jf.12';
			package: 'RSS-Core' with: 'RSS-Core-jf.56';
			package: 'RSS-Examples' with: 'RSS-Examples-dkh.20';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-jf.93';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-dkh.92';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.74';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.79';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.590';
			package: 'Seaside-Development' with: 'Seaside-Development-dkh.122';
			package: 'Seaside-Email' with: 'Seaside-Email-dkh.14';
			package: 'Seaside-Environment' with: 'Seaside-Environment-jf.64';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jf.15';
			package: 'Seaside-Flow' with: 'Seaside-Flow-dkh.18';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-jf.7';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-jf.5';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.68';
			package: 'Seaside-Session' with: 'Seaside-Session-dkh.125';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.12';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-dkh.7';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.11';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-obi.62';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-jf.45';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-jf.90';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.55';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-jf.5';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jf.21';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-dkh.39';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-dkh.27';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-pmm.39';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.26';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-dkh.166';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-jf.32';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-jf.6';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-jf.19';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-jf.6';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.20';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-dkh.94';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-jf.14';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-jf.8';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-jf.9';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.33';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-jf.11';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-pmm.7'.].
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Comet-Core' with: 'Comet-Core-jf.42';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.15';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-jf.3';
			package: 'DynamicBindings' with: 'DynamicBindings-GiovanniCorriga.10';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-jf.2';
			package: 'KomServices' with: 'KomServices-gc.19';
			package: 'KomHttpServer' with: 'KomHttpServer-GiovanniCorriga.50';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.51';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.31';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.20';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-jf.2';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.4';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-jf.3';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-dkh.24';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-dkh.5';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-jf.4';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-jf.3';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-jf.3';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-jf.6';
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.62';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-lr.16';
			package: 'Sport-2' with: 'Sport-2.031';
			package: 'Swazoo-2' with: 'Swazoo-2.2';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-jf.7';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.12';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-jf.11';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.4';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-dkh.6';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-jf.3';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-dkh.7';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-jf.31'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.89';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.12';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.590';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.8';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.38';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.10';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.7'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 12/9/2009 11:17'!
version300alpha502: spec
	<version: '3.0.0-alpha5.2' imports: #('3.0.0-alpha5.2-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up recent changes from Seaside developers (12/9/2009 11:16)
- fix a GemStone compile error in JSStream class>>initializeEncoding [Javascript-Core]
- merge changes from JQuery-Core-lr.90 into JQuery-Core.gemstone-dkh.91
- move Kom, Sport and Swazoo packages to their own configurations
'.
		spec author: 'dkh'.
		spec timestamp: '12/9/2009 11:16'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-dkh.69';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.90';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.42';
			package: 'Prototype-Core' with: 'Prototype-Core-jf.12';
			package: 'RSS-Core' with: 'RSS-Core-jf.56';
			package: 'RSS-Examples' with: 'RSS-Examples-dkh.20';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-jf.93';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-dkh.92';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.74';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.79';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.590';
			package: 'Seaside-Development' with: 'Seaside-Development-dkh.122';
			package: 'Seaside-Email' with: 'Seaside-Email-dkh.14';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.65';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jf.15';
			package: 'Seaside-Flow' with: 'Seaside-Flow-dkh.18';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-jf.7';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-jf.5';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.68';
			package: 'Seaside-Session' with: 'Seaside-Session-dkh.125';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.12';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-dkh.7';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.11';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-lr.65';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-jf.45';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.94';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.56';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-jf.5';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jf.21';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-dkh.39';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-dkh.27';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-jf.40';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.26';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-jf.167';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-jf.32';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-jf.6';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-jf.19';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-jf.6';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.20';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.95';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-jf.14';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-jf.8';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-jf.9';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.33';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-jf.11';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-pmm.7'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'Kom' with: '1.0';
			project: 'SPort2' with: '2.31';
			project: 'Swazoo2' with: '2.2'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-jf.42';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.15';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-jf.3';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-jf.2';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.51';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-lr.32';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.20';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-jf.2';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.4';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-jf.3';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.25';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-dkh.5';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-jf.4';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-jf.3';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-jf.3';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-jf.6';
			package: 'Seaside-Slime' with: 'Seaside-Slime-jf.64';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-lr.16';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-jf.7';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.12';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-jf.11';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.4';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-dkh.6';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-jf.3';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-dkh.7';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-jf.31'.].
	spec for: #gemstone do: [
		spec 
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.12';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.590';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.8';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.38';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.10';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.7'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 12/15/2009 09:56'!
version300alpha503: spec
	<version: '3.0.0-alpha5.3' imports: #('3.0.0-alpha5.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'alpha'.
		spec description: '- use http://www.squeaksource.com/MetacelloRepository as location for Kom, Sport, and Swazoo configs
- Swazoo2 moved to #common as it has been ported to GemStone
'.
		spec author: 'dkh'.
		spec timestamp: '12/14/09 16:58:00'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'Swazoo2' with: '2.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-dkh.69';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.90';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.42';
			package: 'Prototype-Core' with: 'Prototype-Core-jf.12';
			package: 'RSS-Core' with: 'RSS-Core-jf.56';
			package: 'RSS-Examples' with: 'RSS-Examples-dkh.20';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-jf.93';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-dkh.92';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.74';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.79';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.590';
			package: 'Seaside-Development' with: 'Seaside-Development-dkh.122';
			package: 'Seaside-Email' with: 'Seaside-Email-dkh.14';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.65';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jf.15';
			package: 'Seaside-Flow' with: 'Seaside-Flow-dkh.18';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-jf.7';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-jf.5';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.68';
			package: 'Seaside-Session' with: 'Seaside-Session-dkh.125';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.12';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-dkh.7';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.11';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-lr.65';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-jf.45';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-lr.16';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-lr.32';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.94';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.56';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-jf.5';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jf.21';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-dkh.39';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-dkh.27';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-jf.40';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.26';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-jf.167';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-jf.32';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-jf.6';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-jf.19';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-jf.6';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.20';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.95';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-jf.14';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-jf.8';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-jf.9';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.33';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-jf.11';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-pmm.7'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-jf.42';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.15';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-jf.3';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-jf.2';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.51';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.20';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-jf.2';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.4';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-jf.3';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.25';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-dkh.5';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-jf.4';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-jf.3';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-jf.3';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-jf.6';
			package: 'Seaside-Slime' with: 'Seaside-Slime-jf.64';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-jf.7';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.12';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-jf.11';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.4';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-dkh.6';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-jf.3';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-dkh.7';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-jf.31'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.12';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.1';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.590';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.10';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.38';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.10';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 12/31/2009 09:55'!
version300alpha504: spec
	<version: '3.0.0-alpha5.4' imports: #('3.0.0-alpha5.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'alpha'.
		spec description: '- update to development Swazoo version
- concurrent GemStone server gem support for FastCGI and Swazoo2
  - convert class vars to SessionTemps
  - common adaptor code for transactions and request processing
  - server logging and error handlers
  - session object lock to avoid concurrent session access
  - add package Seaside-GemStone-Session
  - add GemStone WAObjectLogErrorHandler ... minimum multi-vm support
  - add WANoReapingStrategy as default reaping strategy for GemStone (use maintenance vm)
  - bullet proof WAGemStoneMutex from concurrency issues
  - support for maintenance vm cache reaping
- make use of allInstances in WARegistry class>> clearAll more GemStone friendly
- add WARcLastAccessExpiryPolicy, a reduced conflict version of WALastAccessExpiryPolicy
'.
		spec author: 'dkh'.
		spec timestamp: '12/29/09 09:42:26'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'Swazoo2' with: '2.2.0.1'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-dkh.69';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.90';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.42';
			package: 'Prototype-Core' with: 'Prototype-Core-jf.12';
			package: 'RSS-Core' with: 'RSS-Core-jf.56';
			package: 'RSS-Examples' with: 'RSS-Examples-dkh.20';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-jf.93';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-dkh.92';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.74';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.79';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.590';
			package: 'Seaside-Development' with: 'Seaside-Development-dkh.122';
			package: 'Seaside-Email' with: 'Seaside-Email-dkh.14';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.65';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jf.15';
			package: 'Seaside-Flow' with: 'Seaside-Flow-dkh.18';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-jf.7';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-jf.5';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.68';
			package: 'Seaside-Session' with: 'Seaside-Session-dkh.125';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.12';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-dkh.7';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.11';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-lr.65';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-jf.45';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-lr.16';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-lr.32';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.94';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.56';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-jf.5';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jf.21';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-dkh.39';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-dkh.27';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-jf.40';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.26';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-jf.167';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-jf.32';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-jf.6';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-jf.19';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-jf.6';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.20';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.95';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-jf.14';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-jf.8';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-jf.9';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.33';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-jf.11';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-pmm.7'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-jf.42';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.15';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-jf.3';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-jf.2';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.51';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.20';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-jf.2';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.4';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-jf.3';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.25';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-dkh.5';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-jf.4';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-jf.3';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-jf.3';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-jf.6';
			package: 'Seaside-Slime' with: 'Seaside-Slime-jf.64';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-jf.7';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.12';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-jf.11';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.4';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-dkh.6';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-jf.3';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-dkh.7';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-jf.31'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 04/21/2010 16:45'!
version300alpha5051: spec
	<version: '3.0.0-alpha5.5.1' imports: #('3.0.0-alpha5.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '- gemstone specific branch of 3.0.0-alpha5.5 for 1.0-beta.8
- bugfix in Seaside-Core.gemstone to turn tests green.
- 1722 run, 1717 passes, 5 expected failures, 0 failures, 0 errors, 0 unexpected passes.
'.
		spec author: 'dkh'.
		spec timestamp: '1/11/2010 16:49'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'Swazoo2' with: '2.2.0.1'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-dkh.69';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.90';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.42';
			package: 'Prototype-Core' with: 'Prototype-Core-jf.12';
			package: 'RSS-Core' with: 'RSS-Core-jf.56';
			package: 'RSS-Examples' with: 'RSS-Examples-dkh.20';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-jf.93';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-dkh.92';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.74';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.79';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.590';
			package: 'Seaside-Development' with: 'Seaside-Development-dkh.122';
			package: 'Seaside-Email' with: 'Seaside-Email-dkh.14';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.65';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jf.15';
			package: 'Seaside-Flow' with: 'Seaside-Flow-dkh.18';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-jf.7';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-jf.5';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.68';
			package: 'Seaside-Session' with: 'Seaside-Session-dkh.125';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.12';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-dkh.7';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.11';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-lr.65';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-jf.45';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-lr.16';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-lr.32';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.94';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.56';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-jf.5';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jf.21';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-dkh.39';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-dkh.27';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-jf.40';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.26';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-jf.167';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-jf.32';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-jf.6';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-jf.19';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-jf.6';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.20';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.95';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-jf.14';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-jf.8';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-jf.9';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.33';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-jf.11';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-pmm.7'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0';
			project: 'OB' with: '1.1';
			project: 'Refactoring-Core' with: '1.0';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-jf.42';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.15';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-jf.3';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-jf.2';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.51';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.20';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-jf.2';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.4';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-jf.3';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.25';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-dkh.5';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-jf.4';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-jf.3';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-jf.3';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-jf.6';
			package: 'Seaside-Slime' with: 'Seaside-Slime-jf.64';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-jf.7';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.12';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-jf.11';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.4';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-dkh.6';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-jf.3';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-dkh.7';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-jf.31'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 1/11/2010 16:52'!
version300alpha505: spec
	<version: '3.0.0-alpha5.5' imports: #('3.0.0-alpha5.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'alpha'.
		spec description: '- adjusted dependencies so that OB/RB is loaded only if ''Seaside-Tools-OmniBrowser''/''Seaside-Slime'' explicitly requested. If OB/RB already present, then those packages loaded by default.
'.
		spec author: 'dkh'.
		spec timestamp: '1/11/2010 16:49'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'Swazoo2' with: '2.2.0.1'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-dkh.69';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.90';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.42';
			package: 'Prototype-Core' with: 'Prototype-Core-jf.12';
			package: 'RSS-Core' with: 'RSS-Core-jf.56';
			package: 'RSS-Examples' with: 'RSS-Examples-dkh.20';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-jf.93';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-dkh.92';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.74';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.79';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.590';
			package: 'Seaside-Development' with: 'Seaside-Development-dkh.122';
			package: 'Seaside-Email' with: 'Seaside-Email-dkh.14';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.65';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jf.15';
			package: 'Seaside-Flow' with: 'Seaside-Flow-dkh.18';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-jf.7';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-jf.5';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.68';
			package: 'Seaside-Session' with: 'Seaside-Session-dkh.125';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.12';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-dkh.7';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.11';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-lr.65';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-jf.45';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-lr.16';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-lr.32';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.94';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.56';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-jf.5';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jf.21';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-dkh.39';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-dkh.27';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-jf.40';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.26';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-jf.167';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-jf.32';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-jf.6';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-jf.19';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-jf.6';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.20';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.95';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-jf.14';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-jf.8';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-jf.9';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.33';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-jf.11';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-pmm.7'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0';
			project: 'OB' with: '1.1';
			project: 'Refactoring-Core' with: '1.0';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-jf.42';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.15';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-jf.3';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-jf.2';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.51';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.20';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-jf.2';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.4';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-jf.3';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.25';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-dkh.5';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-jf.4';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-jf.3';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-jf.3';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-jf.6';
			package: 'Seaside-Slime' with: 'Seaside-Slime-jf.64';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-jf.7';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.12';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-jf.11';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.4';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-dkh.6';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-jf.3';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-dkh.7';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-jf.31'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 1/26/2010 15:35'!
version300alpha506: spec
	<version: '3.0.0-alpha5.6' imports: #('3.0.0-alpha5.6-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up latest developer package versions (1/22/2010 12:06)"
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/26/2010 15:35'.
		spec 
			project: 'Grease' with: '1.0-alpha4';
			project: 'Grease Tests' with: '1.0-alpha4';
			project: 'Swazoo2' with: '2.2.0.1'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-jf.72';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.94';
			package: 'JQuery-UI' with: 'JQuery-UI-jf.46';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.15';
			package: 'RSS-Core' with: 'RSS-Core-pmm.57';
			package: 'RSS-Examples' with: 'RSS-Examples-pmm.22';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.95';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-jf.95';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-obi.86';
			package: 'Seaside-Component' with: 'Seaside-Component-jf.81';
			package: 'Seaside-Core' with: 'Seaside-Core-obi.600';
			package: 'Seaside-Development' with: 'Seaside-Development-obi.127';
			package: 'Seaside-Email' with: 'Seaside-Email-dkh.14';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.66';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jf.15';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.19';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-jf.7';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-jf.5';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.70';
			package: 'Seaside-Session' with: 'Seaside-Session-lr.126';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.14';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-jf.11';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.12';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-jok.72';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-jf.46';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-lr.17';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-lr.32';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.105';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-jf.62';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-jf.5';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jf.21';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-jf.45';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-jf.28';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-obi.42';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.27';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-obi.175';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.33';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.7';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.20';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.7';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.22';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-obi.108';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-lr.15';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-jf.8';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.10';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.33';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.13';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-pmm.7'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'Kom' with: '1.0';
			project: 'OB' with: '1.1';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-jf.44';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.16';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-jf.3';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-lr.3';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-jf.52';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.20';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-jf.2';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.4';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-jf.3';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-jf.27';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-dkh.5';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.5';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-jf.3';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.4';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-obi.12';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-jf.7';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.12';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.12';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.5';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-dkh.6';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-jf.6';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-jf.8'.].
	spec for: #pharo do: [
		spec project: 'Refactoring-Core' with: '1.1'.
		spec
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.70';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.34'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 1/27/2010 17:18'!
version300alpha507: spec
	<version: '3.0.0-alpha5.7' imports: #('3.0.0-alpha5.7-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up latest developer package versions ( 1/27/2010 16:00)
- restructure for parts of Slime being moved to Grease
- 1324 run, 1322 passes, 2 expected failures, 0 failures, 0 errors, 0 unexpected passes
'.
		spec author: 'dkh'.
		spec timestamp: '1/27/2010 16:32'.
		spec 
			project: 'Grease' with: '1.0-alpha5.1';
			project: 'Grease Tests' with: '1.0-alpha5.1';
			project: 'Swazoo2' with: '2.2.0.1'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.74';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.97';
			package: 'JQuery-UI' with: 'JQuery-UI-jf.46';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.15';
			package: 'RSS-Core' with: 'RSS-Core-lr.58';
			package: 'RSS-Examples' with: 'RSS-Examples-pmm.22';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.95';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.98';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-lr.88';
			package: 'Seaside-Component' with: 'Seaside-Component-jf.81';
			package: 'Seaside-Core' with: 'Seaside-Core-jok.606';
			package: 'Seaside-Development' with: 'Seaside-Development-obi.127';
			package: 'Seaside-Email' with: 'Seaside-Email-dkh.14';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.66';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jf.15';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.19';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-jf.7';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-jf.5';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.70';
			package: 'Seaside-Session' with: 'Seaside-Session-lr.126';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.15';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.12';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.12';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-jok.73';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-jf.46';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-lr.17';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-lr.32';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.106';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.63';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-jf.5';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jf.21';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.47';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-obi.29';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-obi.42';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.27';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-jf.176';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.33';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.7';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.20';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.7';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-lr.23';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-jf.112';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-lr.15';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-jf.8';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.10';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.33';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.13';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-pmm.7'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'Kom' with: '1.0';
			project: 'OB' with: '1.1';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-jf.44';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.16';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-jf.3';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-lr.3';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-jf.52';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.20';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-jf.2';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.4';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-jf.4';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-jf.27';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-dkh.5';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.5';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-jf.3';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.4';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-jok.13';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-jf.7';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.12';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.12';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.5';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-dkh.6';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-dkh.7';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.9'.].
	spec for: #pharo do: [
		spec 
			project: 'Grease-Slime' with: '1.0-alpha5.1';
			project: 'Grease-Tests-Slime' with: '1.0-alpha5.1'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.76';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-jok.40'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 2/9/2010 12:12'!
version300alpha508: spec
	<version: '3.0.0-alpha5.8' imports: #('3.0.0-alpha5.7-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up latest Kom (1.0.1)
- pick up latest packages (1/31/2010 17:27)'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/31/2010 17:27'.
		spec 
			project: 'Grease' with: '1.0-alpha5.1';
			project: 'Grease Tests' with: '1.0-alpha5.1';
			project: 'Swazoo2' with: '2.2.0.1'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.74';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.98';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.47';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.15';
			package: 'RSS-Core' with: 'RSS-Core-lr.58';
			package: 'RSS-Examples' with: 'RSS-Examples-pmm.22';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.95';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.98';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.89';
			package: 'Seaside-Component' with: 'Seaside-Component-jf.81';
			package: 'Seaside-Core' with: 'Seaside-Core-jf.608';
			package: 'Seaside-Development' with: 'Seaside-Development-obi.127';
			package: 'Seaside-Email' with: 'Seaside-Email-dkh.14';
			package: 'Seaside-Environment' with: 'Seaside-Environment-jf.67';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jf.15';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.19';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-jf.7';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-jf.5';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.70';
			package: 'Seaside-Session' with: 'Seaside-Session-lr.126';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.15';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.12';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.12';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-jok.73';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.47';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-lr.17';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-jf.33';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.107';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.64';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-jf.5';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jf.21';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.47';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-obi.29';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.43';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.27';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-jf.177';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.33';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.7';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.20';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.7';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-lr.23';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-jf.113';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-lr.15';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-jf.8';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.10';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.33';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.13';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-pmm.7'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'Kom' with: '1.0.1';
			project: 'OB' with: '1.1';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-jf.44';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.16';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-jf.3';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-lr.3';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-jf.53';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-jf.21';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-jf.2';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.4';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-jf.4';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-jf.27';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-dkh.5';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.5';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-jf.3';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.4';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-jok.13';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-jf.7';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.12';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.12';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.5';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-dkh.6';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-dkh.7';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.9'.].
	spec for: #pharo do: [
		spec 
			project: 'Grease-Slime' with: '1.0-alpha5.1';
			project: 'Grease-Tests-Slime' with: '1.0-alpha5.1'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.76';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-jok.40'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 3/1/2010 14:55'!
version300alpha509: spec
	<version: '3.0.0-alpha5.9' imports: #('3.0.0-alpha5.9-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up Grease 1.0-alpha6
- pick up latest mcz files (3/1/2010 13:31)'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/1/2010 13:31'.
		spec 
			project: 'Grease' with: '1.0-alpha6';
			project: 'Grease Tests' with: '1.0-alpha6';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.83';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.103';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.52';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.19';
			package: 'RSS-Core' with: 'RSS-Core-lr.59';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.99';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-lr.94';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.82';
			package: 'Seaside-Core' with: 'Seaside-Core-lr.625';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.133';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.69';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.17';
			package: 'Seaside-Flow' with: 'Seaside-Flow-lr.21';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.9';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-lr.6';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-jf.130';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.17';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.16';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.14';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-lr.78';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.54';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-lr.36';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.112';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.73';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.8';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.22';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.52';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.31';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.46';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.28';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-lr.187';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.34';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.8';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.22';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.8';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-lr.25';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-jf.118';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-lr.16';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.36';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.14';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.8'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'Kom' with: '1.0.1';
			project: 'OB' with: '1.1';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.49';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.17';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-lr.7';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.55';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-lr.5';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.39';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.5';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-lr.21';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.6';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-lr.8';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-lr.9';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.11'.].
	spec for: #pharo do: [
		spec 
			project: 'Grease-Slime' with: '1.0-alpha6';
			project: 'Grease-Tests-Slime' with: '1.0-alpha6'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.77';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.41'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 3/29/2010 12:41'!
version300alpha510: spec
	<version: '3.0.0-alpha5.10' imports: #('3.0.0-alpha5.9-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up Grease 1.0-alpha7
- pick up latest mcz files (3/29/2010 11:20)'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/29/2010 11:27'.
		spec 
			project: 'Grease' with: '1.0-alpha7';
			project: 'Grease Tests' with: '1.0-alpha7';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.84';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.103';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.55';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.19';
			package: 'RSS-Core' with: 'RSS-Core-lr.59';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.99';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-lr.94';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.82';
			package: 'Seaside-Core' with: 'Seaside-Core-jok.628';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.133';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.69';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jok.18';
			package: 'Seaside-Flow' with: 'Seaside-Flow-lr.21';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.9';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-lr.6';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-jf.130';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.17';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.16';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.14';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-lr.79';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.54';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-lr.36';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.113';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.74';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.9';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.22';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.52';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.31';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.46';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.28';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-jok.188';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.34';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.8';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.22';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.8';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-lr.25';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-jf.118';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jok.37';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.14';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.8'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'Kom' with: '1.0.1';
			project: 'OB' with: '1.1';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.49';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.18';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-lr.7';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.55';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-lr.5';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-jok.40';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.5';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-lr.21';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.6';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-lr.8';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-jok.10';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.11'.].
	spec for: #pharo do: [
		spec 
			project: 'Grease-Slime' with: '1.0-alpha6';
			project: 'Grease-Tests-Slime' with: '1.0-alpha6'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.77';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.41'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 5/12/2010 16:37'!
version300alpha511: spec
	<version: '3.0.0-alpha5.11' imports: #('3.0.0-alpha5.11-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- pick up Grease 1.0-alpha8
- pick up latest mcz files (4/9/2010 15:54)
- never released and bypassed by 3.0.0-alpha5.12'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '4/9/2010 16:03'.
		spec 
			project: 'Grease' with: '1.0-alpha8';
			project: 'Grease Tests' with: '1.0-alpha8';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.84';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.104';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.55';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.19';
			package: 'RSS-Core' with: 'RSS-Core-lr.59';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.99';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-lr.94';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.82';
			package: 'Seaside-Core' with: 'Seaside-Core-jok.628';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.133';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.69';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jok.18';
			package: 'Seaside-Flow' with: 'Seaside-Flow-lr.21';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.9';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-lr.6';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-jf.130';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.17';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.16';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.14';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-lr.79';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.56';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-lr.36';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.116';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.75';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.10';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.23';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.53';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.31';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.47';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.29';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-lr.189';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.9';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.23';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-lr.26';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-jf.118';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.38';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'Kom' with: '1.0.1';
			project: 'OB' with: '1.1';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.49';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.18';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-lr.7';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.55';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-lr.6';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.41';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.5';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-lr.21';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.10';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-lr.9';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-lr.11';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #pharo do: [
		spec 
			project: 'Grease-Slime' with: '1.0-alpha6';
			project: 'Grease-Tests-Slime' with: '1.0-alpha6'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.77';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 5/12/2010 17:53'!
version300alpha512: spec
	<version: '3.0.0-alpha5.12' imports: #('3.0.0-alpha5.11-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up Grease 1.0-alpha9
- pick up OmniBrowser 1.1.4 for Pharo1.1 compatibility
- pick up latest mcz files (5/12/2010 16:33)
- 1593 run, 1591 passes, 2 expected failures, 0 failures, 0 errors, 0 unexpected passes (Pharo1.0)
- 1605 run, 1571 passes, 2 expected failures, 13 failures, 19 errors, 0 unexpected passes (Pharo1.1)
- 1560 run, 1555 passes, 2 expected failures, 0 failures, 3 errors, 0 unexpected passes (Squeak4.1)
- Seaside-Sport and Seaside-Adaptors-Hyper not yet integrated
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '5/12/2010 16:33'.
		spec 
			project: 'Grease' with: '1.0-alpha9';
			project: 'Grease Tests' with: '1.0-alpha9';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.85';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.105';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.56';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.19';
			package: 'RSS-Core' with: 'RSS-Core-jok.60';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.99';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-lr.94';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.82';
			package: 'Seaside-Core' with: 'Seaside-Core-jok.632';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.133';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.69';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jok.18';
			package: 'Seaside-Flow' with: 'Seaside-Flow-lr.21';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.9';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-lr.6';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-jf.130';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.17';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-jok.17';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.14';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-jok.80';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.57';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.119';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.77';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.11';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jok.24';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.54';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.31';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.47';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.29';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.191';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.9';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.23';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-lr.26';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-jf.118';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.38';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'Kom' with: '1.0.1';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.49';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.18';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-lr.7';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.57';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-lr.6';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.41';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-lr.21';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.10';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-lr.9';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-lr.11';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #pharo do: [
		spec 
			project: 'Grease-Slime' with: '1.0-alpha6';
			project: 'Grease-Tests-Slime' with: '1.0-alpha6'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.77';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 5/14/2010 17:09'!
version300alpha513: spec
	<version: '3.0.0-alpha5.13' imports: #('3.0.0-alpha5.11-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up Grease 1.0-alpha9.1
- pick up latest mcz files for Pharo1.1 compat (5/14/2010 13:25)
- 1593 run, 1591 passes, 2 expected failures, 0 failures, 0 errors, 0 unexpected passes (Pharo1.0)
- 1593 run, 1591 passes, 2 expected failures, 0 failures, 0 errors, 0 unexpected passes (Pharo1.1)
- Seaside-Sport and Seaside-Adaptors-Hyper not yet integrated
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '5/14/2010 13:47'.
		spec 
			project: 'Grease' with: '1.0-alpha9.1';
			project: 'Grease Tests' with: '1.0-alpha9.1';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.85';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.105';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.56';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.19';
			package: 'RSS-Core' with: 'RSS-Core-jok.60';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.99';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-lr.94';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.82';
			package: 'Seaside-Core' with: 'Seaside-Core-jok.632';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.133';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.69';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jok.18';
			package: 'Seaside-Flow' with: 'Seaside-Flow-lr.21';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.9';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-lr.6';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-jf.130';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.17';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-jok.17';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.14';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-jok.80';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.57';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.119';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.77';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.11';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jok.24';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.54';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.31';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.47';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.29';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-lr.192';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.9';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.23';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-lr.26';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-jf.118';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.38';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'Kom' with: '1.0.1';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.49';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.18';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-lr.7';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.57';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-lr.7';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.41';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-lr.21';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.10';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-lr.9';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-lr.11';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #pharo do: [
		spec 
			project: 'Grease-Slime' with: '1.0-alpha6';
			project: 'Grease-Tests-Slime' with: '1.0-alpha6'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.77';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 6/1/2010 14:34'!
version300alpha514: spec
	<version: '3.0.0-alpha5.14' imports: #('3.0.0-alpha5.11-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up latest mcz files(6/1/2010 10:21)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '6/1/2010 10:21'.
		spec 
			project: 'Grease' with: '1.0-alpha9.2';
			project: 'Grease Tests' with: '1.0-alpha9.2';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.85';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.105';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.56';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.21';
			package: 'RSS-Core' with: 'RSS-Core-jok.60';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.95';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.82';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.643';
			package: 'Seaside-Development' with: 'Seaside-Development-jf.134';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.69';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jok.18';
			package: 'Seaside-Flow' with: 'Seaside-Flow-lr.21';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.9';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-lr.6';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-jf.132';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.17';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.15';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-jf.81';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.57';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.119';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.77';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.11';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jok.24';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-pmm.49';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.29';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-jf.194';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.9';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.23';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-YM.27';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-YM.120';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-pmm.39';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'Kom' with: '1.0.2';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.49';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.18';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-lr.7';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.59';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-lr.7';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.41';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-lr.21';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.10';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-lr.9';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-lr.11';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #pharo do: [
		spec 
			project: 'Grease-Slime' with: '1.0-alpha6';
			project: 'Grease-Tests-Slime' with: '1.0-alpha6'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.77';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'Grease' with: '1.0-alpha3';
			project: 'Grease Tests' with: '1.0-alpha3';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.235'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-dkh.1';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-dkh.91';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.43';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-dkh.13';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.14';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.2';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.595';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-dkh.14';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.44';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.3';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.5';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-dkh.2';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-dkh.3';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-dkh.2';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.125';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.11';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.8'.].
	spec for: #'gs2.3.x' do: [
		spec 
			removePackage: 'JQuery-Tests-Core';
			removePackage: 'JQuery-Tests-UI';
			removePackage: 'Scriptaculous-Components';
			removePackage: 'Scriptaculous-Tests-Components';
			removePackage: 'Seaside-Development';
			removePackage: 'Seaside-Flow';
			removePackage: 'Seaside-Tests-Development';
			removePackage: 'Seaside-Tests-Flow'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'JQuery-Tests-GemStone-Core' with: 'JQuery-Tests-GemStone-Core-dkh.1';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-dkh.19';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-dkh.6';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-dkh.3';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-dkh.9';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.1'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 07/13/2010 16:55'!
version300alpha515: spec
	<version: '3.0.0-alpha5.15' imports: #('3.0.0-alpha5.15-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'port to GemStone GLASS 1.0-beta.8
  - remote debugging (disable ''Proceed'' for remote debugging until  Issue 128 is fixed: http://code.google.com/p/glassdb/issues/detail?id=128
  - object log tool
- pick up latest mcz files (6/21/2010 14:32)
- dependencies restructured
- fix Issue 573: http://code.google.com/p/seaside/issues/detail?id=573 "Javascript-Core extends the classes True and False, which don''t exist in GemStone"
- fix Issue 574: http://code.google.com/p/seaside/issues/detail?id=574 "MessageSend>>numArgs is part of PharoCore 1.0"
- added ''Base'' group as per discussion with Julian ... keeping ''Core'' group around (no change to it''s definition, yet)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '07/13/10 16:55:35'.
		spec 
			project: 'Grease Core' with: '1.0-alpha9.3';
			project: 'Grease Core Tests' with: '1.0-alpha9.3';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-DaleHenrichs.87';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.106';
			package: 'JQuery-UI' with: 'JQuery-UI-obi.58';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.21';
			package: 'RSS-Core' with: 'RSS-Core-jok.60';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.95';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.82';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.648';
			package: 'Seaside-Development' with: 'Seaside-Development-jf.134';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-lr.69';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jok.18';
			package: 'Seaside-Flow' with: 'Seaside-Flow-lr.21';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.9';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-lr.6';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-jf.132';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.17';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.15';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-obi.89';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-obi.12';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.57';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-obi.121';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.77';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.11';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jok.24';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-pmm.49';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.29';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.195';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.9';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.23';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-YM.27';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-obi.121';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-pmm.39';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.2';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.49';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.19';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.59';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.9';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.42';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-lr.21';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.10';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.12';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-DaleHenrichs.13';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0-alpha9.3';
			project: 'Grease Slime Tests' with: '1.0-alpha9.3'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.77';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.239'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.2';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-DaleHenrichs.107';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.60';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-DaleHenrichs.22';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.21';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.3';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.96';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.649';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-DaleHenrichs.24';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.54';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.6';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.6';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.3';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.134';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.13';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.20';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.10';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-DaleHenrichs.7';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.10';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.2'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 07/29/2010 17:19'!
version300rc1: spec
	<version: '3.0.0-rc.1' imports: #('3.0.0-rc-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- picked up latest packages (7/29/2010 17:19)
Comet:
  - fixed the font-family in css
JQuery:
  - added JQueryClass>>document for easier document constructor
  - fix Issue 576:	#callbackTabs: in jquery-ui public extension to JQAjax
Javascript:
  - Issue 585:	Parameters in AJAX requests are not always properly encoded
RSS:
  - like application read charSet from requestContext if possible
Comanche Adaptor:
  - try to avoid startup/shutdown problems, comanche cares itself when the server needs to start/stop
  - use HttpRequest >> #rawRequestContents when available
Seaside-Component:
  - http://code.google.com/p/seaside/issues/detail?id=586
  - class name is a Symbol in VW
Seaside-Core:
  - Fix typo in WARequestHandlerConfiguration>>#describeOn: Charater -> Character
  - http://code.google.com/p/seaside/issues/detail?id=586
Seaside-Development:
  - fix tool icons again
  - fixed the font-family in css
Seaside-Examples:
  - fixed the font-family in css
Seaside-Pharo_Development:
  - memory profile: do not follow into the application and the memory profiler itself, otherwise the complete dispatcher tree ends up in the statistic (-> sane numbers again)
Seaside-Slime:
  - #checkClass: is not guarnateed to be called first, make sure that all variables are initialized
Seaside-Tests-Component:
  - added a test for changes made to fix: http://code.google.com/p/seaside/issues/detail?id=586
Seaside-Tools-Web
  - fix some styles because of the font-size changes
  - add dispatcher URL to to path
  - fixed the font-family in css
Seaside-Welcome:
  - changed:
	Smalltalk at: componentName
    to:
	Smalltalk globals at: componentName
  - Fixed Squeak/Pharo cross platform difference in the component creator,  Pharo had a helper for component creation, Squeak requires all parameters to be specified.
  - #[] used in WAWelcomeFiles>>backgroundJpg is not portable use #() asByteArray instead (see WAWelcomeFiles>>seasidestarPng)
  - avoid overlapping of the buttons at WAWelcomeBrowse
  - use the title instead of the long button names

Seaside-Adaptors-FastCGI
  - PUT support

- fix GemStone Issue 152: http://code.google.com/p/glassdb/issues/detail?id=152 "JQuery UI Autocomplete example is broken"
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '07/29/10 12:39:28'.
		spec 
			project: 'Grease Core' with: '1.0-rc';
			project: 'Grease Core Tests' with: '1.0-rc';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.88';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.107';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.59';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.21';
			package: 'RSS-Core' with: 'RSS-Core-pmm.61';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.95';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.85';
			package: 'Seaside-Core' with: 'Seaside-Core-NickAger.651';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.137';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-jf.70';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.19';
			package: 'Seaside-Flow' with: 'Seaside-Flow-lr.21';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.9';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-lr.6';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-jf.132';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.15';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-obi.92';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-DaleHenrichs.25';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.58';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.123';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.78';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.11';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jok.25';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-pmm.49';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.195';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.9';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.23';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-YM.27';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-jf.122';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-pmm.39';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.3';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-obi.50';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.21';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.62';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.9';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.43';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-lr.21';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.10';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.12';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-DaleHenrichs.13';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0-rc';
			project: 'Grease Slime Tests' with: '1.0-rc'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.239'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.3';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-DaleHenrichs.108';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.63';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-DaleHenrichs.22';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.22';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.3';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.96';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.652';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-DaleHenrichs.24';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.57';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.6';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.6';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.3';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.134';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.13';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.20';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.10';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-DaleHenrichs.7';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.10';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.2'.].
	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 08/27/2010 13:15'!
version300rc2: spec
	<version: '3.0.0-rc.2' imports: #('3.0.0-rc.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- finish basic port to GemStone 3.0
- fix a problem with forwarded host/server fields [GemStone]
- increasing delays on retry [GemStone]
- session stats for Seaside 3.0 [GemStone]
  0 - request count (oncoming)
  1 - response count (outgoing)
  2 - request retries
- latest packages as of 8/27/2010 12:02
- Comet
  - made sure that sessions that push through a comet handler do not timeout
- JQuery-UI
  - Issue 590:	JQBaseTheme does not respect SSL
  - http://code.google.com/p/seaside/issues/detail?id=590
  - use #isSsl from WARequest
  - updated to jQuery UI 1.8.4
- Prototype-Core
  - fixed naming on constructor method that caused a lint error on "on invalid object initiailization"
- RSS-Core
  - Issue 493: RSS ignoring updateRoot: stuff
  - http://code.google.com/p/seaside/issues/detail?id=493
- RSS-Tests
  - Issue 493: RSS ignoring updateRoot: stuff
  - http://code.google.com/p/seaside/issues/detail?id=493
- Seaside-Canvas
  - add #basicFrom:
  - fixed bug with #with: causing date and time selectors appear twice (thanks to the annonymous reporter in the comments of the Seaside Book)
  - fixes "Issue 595:	Deselection from a multi selection field does not work"
- Seaside-Core
  - Issue 590:	JQBaseTheme does not respect SSL
  - http://code.google.com/p/seaside/issues/detail?id=590
  - add #isSsl to WARequest and WAUrl
  - Update version number for 3.0
  - Issue 593: expired session cookie deletion fails if server hostname is set
  - http://code.google.com/p/seaside/issues/detail?id=593  
  - Issue 594: #style methods don''t work then session cookies are enabled
  - http://code.google.com/p/seaside/issues/detail?id=594
  - re-added #hasCookieInContext:, it is required by other software
  - removed unused variables
  - Issue 554: WABuilder>>codec should try WACurrentRequestContext first before using GRNullCodec
  - refactor the #perform: out of it so that the file library is responsible for returning the size of a file
  - http://code.google.com/p/seaside/issues/detail?id=554
- Seaside-Development
  - better format #style method
  - removed unsent code that was broken: WAPrettyPrintedDocument>>#close:  
- Seaside-Environment
  - Issue 554: WABuilder>>codec should try WACurrentRequestContext first before using GRNullCodec
  - refactor the #perform: out of it so that the file library is responsible for returning the size of a file
  - http://code.google.com/p/seaside/issues/detail?id=554
- Seaside-Flow
  - Remove #isolate: temporarily for 3.0 final release
  - http://code.google.com/p/seaside/issues/detail?id=553
  - It will be put back in the 3.1 repository.
- Seaside-HTML5
  - add #placeholder:
  - removed #placeholder:, it is already defined in abstract superclass
- Seaside-InternetExplorer
  - remove non-printable character from comment
- Seaside-Pharo-Tools-Web
  - Issue 479: WAGarbageCollectorStatus can result in ZeroDivide exception
  - http://code.google.com/p/seaside/issues/detail?id=479
- Seaside-Session
  - Issue 594: #style methods don''t work then session cookies are enabled
  - http://code.google.com/p/seaside/issues/detail?id=594
- Seaside-Tests-Canvas
  - fixes "Issue 595:	Deselection from a multi selection field does not work"
- Seaside-Tests-Core
  - Issue 590:	JQBaseTheme does not respect SSL
  - http://code.google.com/p/seaside/issues/detail?id=590
  - add #isSsl to WARequest and WAUrl
  - Issue 593: expired session cookie deletion fails if server hostname is set
  - http://code.google.com/p/seaside/issues/detail?id=593
  - Issue 594: #style methods don''t work then session cookies are enabled
  - http://code.google.com/p/seaside/issues/detail?id=594
- Seaside-Tests-Environment
  - regression test
  -  Issue 525:  	 WALegacyRedirectionHandler loses url parameters during redirection
  - http://code.google.com/p/seaside/issues/detail?id=525
- Seaside-Tests-Flow
  - Remove #isolate: temporarily for 3.0 final release
  - http://code.google.com/p/seaside/issues/detail?id=553
  - It will be put back in the 3.1 repository.
- Seaside-Tests-Functional
  - fixed bug with #with: causing date and time selectors appear twice (thanks to the annonymous reporter in the comments of the Seaside Book)
  - don''t test character by character rendering for null codec
- Seaside-Tests-Pharo-Core
  -  Issue 570:  	 iso-8859-1 doesn''t show up in the encoding list of the server adapter
  - http://code.google.com/p/seaside/issues/detail?id=570
- Seaside-Tests-Session
  - Issue 593: expired session cookie deletion fails if server hostname is set
 - http://code.google.com/p/seaside/issues/detail?id=593
  - Issue 594: #style methods don''t work then session cookies are enabled
  - http://code.google.com/p/seaside/issues/detail?id=594
   removed unused variables
- Seaside-Tools-OmniBrowser
  - improved reordering of commands in browser
  - display the encoding in the list of server adaptor
  - removed "start/stop all" commands, seem to be less useful
- Seaside-Welcome
 - Added JQScriptGenerator preference to component registration and overrode the JQueryUI ui-widget-overlay so that the alpha blended background to a popup doesn''t look like a headache inducing moir pattern 
  - categorize methods
  - simplify rendering
  - removed unused variables
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '08/27/2010 12:32:08'.
		spec 
			project: 'Grease Core' with: '1.0-rc.1';
			project: 'Grease Core Tests' with: '1.0-rc.1';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.88';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.107';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.62';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.22';
			package: 'RSS-Core' with: 'RSS-Core-pmm.62';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-lr.98';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.85';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.659';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.139';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.71';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.19';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.22';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.11';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.134';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.17';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-obi.92';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-lr.28';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.58';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.123';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.78';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.11';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-pmm.26';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.50';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.198';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.9';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.24';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.28';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.124';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.42';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.3';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.21';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.62';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.9';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.43';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.22';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.10';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.14';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-DaleHenrichs.13';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0-rc.1';
			project: 'Grease Slime Tests' with: '1.0-rc.1'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.239'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.3';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.64';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.23';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.3';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.99';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-DaleHenrichs.24';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.60';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.20';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.6';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.6';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-DaleHenrichs.8';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.3';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.135';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.10';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.13';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.2';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.660';
			package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'.].
	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.653';
			package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 09/03/2010 09:49'!
version300rc3: spec
	<version: '3.0.0-rc.3' imports: #('3.0.0-rc.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'GemStone bugfixes:
- fix Issue 156: http://code.google.com/p/glassdb/issues/detail?id=156 "WAGsSwazooAdaptor should have defaultCodec set to GRUtf8GemStoneCodec"
- fix Issue 165: http://code.google.com/p/glassdb/issues/detail?id=165 "Include GemStone version of Seaside-FileSystem in Seaside3.0"
- fix Issue 170: http://code.google.com/p/glassdb/issues/detail?id=170 "Errors during Ajax requests can crash vm"
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '09/02/2010 16:43:25'.
		spec 
			project: 'Grease Core' with: '1.0-rc.2';
			project: 'Grease Core Tests' with: '1.0-rc.2';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.88';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.107';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.62';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.22';
			package: 'RSS-Core' with: 'RSS-Core-pmm.62';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-lr.98';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.85';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.659';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.139';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.71';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.19';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.22';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.11';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.134';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.17';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-obi.92';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-lr.28';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.58';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.123';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.78';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.11';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-pmm.26';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.50';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.198';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.9';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.24';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.28';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.124';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.42';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.3';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.21';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.62';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.9';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.43';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.22';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.10';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.14';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-DaleHenrichs.13';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0-rc.2';
			project: 'Grease Slime Tests' with: '1.0-rc.2'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.239'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.3';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.64';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.23';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.99';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem.gemstone-DaleHenrichs.24';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-DaleHenrichs.24';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.60';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.21';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.6';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.6';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-DaleHenrichs.8';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.3';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.135';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.10';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.14';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.2';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.660';
			package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'.].
	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.653';
			package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 07/27/2010 12:47'!
version300rc: spec
	<version: '3.0.0-rc' imports: #('3.0.0-rc-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- Seaside3.0 release candidate
- port Seaside3.0 to GemStone 3.0
-define ''OneClick'' group for Pharo and Squeak ... not needed for GemStone'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '7/23/2010 16:22'.
		spec 
			project: 'Grease Core' with: '1.0-rc';
			project: 'Grease Core Tests' with: '1.0-rc';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-DaleHenrichs.87';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.106';
			package: 'JQuery-UI' with: 'JQuery-UI-obi.58';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.21';
			package: 'RSS-Core' with: 'RSS-Core-jok.60';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.96';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.95';
			package: 'Seaside-Component' with: 'Seaside-Component-lr.82';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.648';
			package: 'Seaside-Development' with: 'Seaside-Development-jf.135';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.15';
			package: 'Seaside-Environment' with: 'Seaside-Environment-jf.70';
			package: 'Seaside-Examples' with: 'Seaside-Examples-jok.18';
			package: 'Seaside-Flow' with: 'Seaside-Flow-lr.21';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.9';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-lr.6';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-jf.132';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-jf.15';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-obi.89';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-DaleHenrichs.20';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.57';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-obi.121';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.77';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.11';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-jok.25';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-pmm.49';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-lr.29';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.195';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.9';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.23';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-YM.27';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-jf.122';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-pmm.39';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'Kom' with: '1.0.3';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-obi.50';
			package: 'Comet-Examples' with: 'Comet-Examples-obi.20';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.60';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-lr.23';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.9';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.42';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.6';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-lr.21';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.10';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.12';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-DaleHenrichs.13';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #pharo do: [
		spec 
			project: 'Grease Slime' with: '1.0-rc';
			project: 'Grease Slime Tests' with: '1.0-rc'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.77';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #gemstone do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.239'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.2';
			package: 'JQuery-Core' with: 'JQuery-Core.gemstone-DaleHenrichs.107';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.60';
			package: 'Prototype-Core' with: 'Prototype-Core.gemstone-DaleHenrichs.22';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.21';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.3';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.96';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.649';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-DaleHenrichs.24';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.57';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.6';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.6';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.3';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.134';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.13';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.20';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.10';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-DaleHenrichs.7';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.10';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.2'.].
	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 11/19/2010 12:34'!
version3011: spec
	<version: '3.0.1.1' imports: #('3.0.1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- pick up latest mcz files'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '11/17/2010 13:20:39'.
		spec 
			project: 'Grease Core' with: '1.0.1.1';
			project: 'Grease Core Tests' with: '1.0.1.1';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.88';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.112';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.69';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.23';
			package: 'RSS-Core' with: 'RSS-Core-pmm.62';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.97';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.101';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.85';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.666';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.140';
			package: 'Seaside-Email' with: 'Seaside-Email-pmm.19';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.71';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.19';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.25';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.22';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.11';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.134';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.18';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.93';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-NickAger.34';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.58';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.125';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.79';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.12';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.27';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.51';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.201';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-pmm.11';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.24';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.28';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.125';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.42';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-NickAger.4'.].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.6';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.22';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.64';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.9';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.44';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-pmm.9';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.23';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.14';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-DaleHenrichs.13';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'.].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.1';
			project: 'Grease Slime Tests' with: '1.0.1'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.242';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.239'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.3';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.70';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.23';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.102';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-DaleHenrichs.24';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.60';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.21';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.6';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.8';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-NorbertHartl.9';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.3';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.135';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.10';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.14';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.2';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'.].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.667';
			package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'.].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.653';
			package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'.].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 11/11/2010 13:13'!
version301: spec
	<version: '3.0.1' imports: #('3.0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- pick up recent .mcz files
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '11/09/2010 12:53:43'.
		spec 
			project: 'Grease Core' with: '1.0.1';
			project: 'Grease Core Tests' with: '1.0.1';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.88';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.111';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.69';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.23';
			package: 'RSS-Core' with: 'RSS-Core-pmm.62';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.97';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.101';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.85';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.666';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.140';
			package: 'Seaside-Email' with: 'Seaside-Email-pmm.19';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.71';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.19';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.25';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.22';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.11';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.134';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.18';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.93';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-NickAger.34';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.58';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.124';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.79';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.12';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.27';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.51';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.201';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-pmm.11';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.24';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.28';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.125';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.42';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-NickAger.4'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.6';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.22';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.64';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.9';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.44';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-pmm.9';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.23';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.14';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-DaleHenrichs.13';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'.].
	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.1';
			project: 'Grease Slime Tests' with: '1.0.1'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.242';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.239'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.3';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.70';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.23';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.102';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-DaleHenrichs.24';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.60';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.21';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.6';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.8';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-NorbertHartl.9';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.3';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.135';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.10';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.14';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.2';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.667';
			package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'.].
	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.653';
			package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 11/22/2010 12:31'!
version302: spec
	<version: '3.0.2' imports: #('3.0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- pick up latest mcz files'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '11/22/2010 12:31:32'.
		spec 
			project: 'Grease Core' with: '1.0.2';
			project: 'Grease Core Tests' with: '1.0.2';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.88';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.112';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.69';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.23';
			package: 'RSS-Core' with: 'RSS-Core-pmm.62';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.97';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.101';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.85';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.667';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.140';
			package: 'Seaside-Email' with: 'Seaside-Email-pmm.19';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.71';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.19';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.25';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.22';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.11';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.134';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.18';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.93';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-NickAger.34';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.58';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.125';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.79';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.12';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.27';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.51';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.201';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-pmm.11';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.24';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.28';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.125';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.42';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-NickAger.4'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.6';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.22';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.64';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.9';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.44';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-pmm.9';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.23';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.14';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-DaleHenrichs.13';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].
	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'.].
	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.2';
			project: 'Grease Slime Tests' with: '1.0.2'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.242';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.239'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.3';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.70';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.23';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.102';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-DaleHenrichs.24';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.60';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.21';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.6';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.8';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-NorbertHartl.9';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.3';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.135';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.10';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.14';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.2';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'.].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.668';
			package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'.].
	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.653';
			package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'.].! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'DaleHenrichs 02/17/2011 12:21'!
version3031: spec
	<version: '3.0.3.1' imports: #('3.0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- get Seaside3.0 running on GemStone3.0beta3
- ExceptionSet handling fixed in GemStone3.0, no longer need special version of Seaside-Core
- WAFlowPlatformTest>>testSuspendCallbackDo passes in GemStone3.0
- Adjust continuation tests ... in GemStone3.0, not possible to unify home context VC after installing a partical continuation ... from code inspection, it doesn''t look like an issue 
- test case to cover bug found in GemStone3.0'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '01/27/2011 14:16:22'.
		spec 
			project: 'Grease Core' with: '1.0.3.1';
			project: 'Grease Core Tests' with: '1.0.3.1';
			project: 'Swazoo2' with: '2.2.0.3'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.88';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.112';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.69';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.23';
			package: 'RSS-Core' with: 'RSS-Core-pmm.62';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.97';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.101';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.85';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.675';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.140';
			package: 'Seaside-Email' with: 'Seaside-Email-pmm.19';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.71';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.19';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.25';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.22';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.11';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.134';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-pmm.21';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.93';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-NickAger.34';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.58';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.125';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.79';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.12';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.27';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.51';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.205';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-pmm.11';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.24';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.28';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.125';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.42';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-NickAger.4'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.7';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.22';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.66';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.9';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.44';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-pmm.9';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.23';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.14';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-DaleHenrichs.13';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.3';
			project: 'Grease Slime Tests' with: '1.0.3'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.240';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.240'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.3';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.70';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.23';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.675';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.102';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-DaleHenrichs.24';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.60';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.23';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.7';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.8';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.16';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-NorbertHartl.9';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.135';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.14';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.3';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 12/13/2010 18:18'!
version303: spec
	<version: '3.0.3' imports: #('3.0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- http://code.google.com/p/seaside/wiki/Seaside303Changelog
- fix Issue 186: http://code.google.com/p/glassdb/issues/detail?id=186 "WAFileLibrary>>deployFiles fail if folder already exists" [GemStone]
- fix Issue 169: http://code.google.com/p/glassdb/issues/detail?id=169 "Incorporate GemStone Futures code from Nick Ager" [GemStone]
- fix Issue 191: http://code.google.com/p/glassdb/issues/detail?id=191 "getting object log continuation for rest api calls" [GemStone]'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '12/13/2010 15:39:25'.
		spec 
			project: 'Grease Core' with: '1.0.3';
			project: 'Grease Core Tests' with: '1.0.3';
			project: 'Swazoo2' with: '2.2.0.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.88';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.112';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.69';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.23';
			package: 'RSS-Core' with: 'RSS-Core-pmm.62';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-lr.97';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-obi.105';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.101';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.85';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.675';
			package: 'Seaside-Development' with: 'Seaside-Development-lr.140';
			package: 'Seaside-Email' with: 'Seaside-Email-pmm.19';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.71';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.19';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.25';
			package: 'Seaside-Flow' with: 'Seaside-Flow-jf.22';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.11';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.134';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-obi.18';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-pmm.21';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.93';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-NickAger.34';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-lr.58';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.37';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.125';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.79';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.12';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.27';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-lr.56';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.33';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-lr.51';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.205';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-lr.35';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-pmm.11';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.24';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-jf.28';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.125';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.17';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.42';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.15';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-NickAger.4'.].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.7';
			project: 'OB' with: '1.1.4';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.22';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.66';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.9';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.44';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-pmm.9';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.23';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-lr.13';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.14';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-DaleHenrichs.13';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'.].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'.].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.3';
			project: 'Grease Slime Tests' with: '1.0.3'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'.].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.242';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: '0.240'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.3';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.70';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.23';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.102';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-DaleHenrichs.24';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.60';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.22';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.7';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.8';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.16';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-NorbertHartl.9';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.135';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.10';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.14';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.2';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'.].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.675';
			package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'.].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.653';
			package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'.].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 3/3/2011 15:30'!
version304: spec
	<version: '3.0.4' imports: #('3.0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- latest mcz files for 3.0.4 see http://code.google.com/p/seaside/wiki/Seaside304Changelog
- fix Issue 231: "WABasicDevelopment>>#reapSeasideCache, assumes WADispatcher>>#default returns a WADispatcher"  [GemStone]
  http://code.google.com/p/glassdb/issues/detail?id=231
- fix Issue 239: "using WAFastCGIAdaptor leads the false conversion of + in urls. [GemStone]"
  http://code.google.com/p/glassdb/issues/detail?id=239
- fix Issue 217: MultibyteString JavascriptOn infinite recursion [GemStone]
  http://code.google.com/p/glassdb/issues/detail?id=217
- add JSJsonStreamTest>>testStringMultiByte to common test suite
- fix Issue 221: JQAutocomplete broken on GemStone
  http://code.google.com/p/glassdb/issues/detail?id=221
- fix up Seaside-Tests-Pharo-Development for new package: Seaside-Tests-Pharo-Email
- fix for Issue 643: load 3.0.4 on top of 3.0.3 results in tests hitting WAAttributeNotFound
  http://code.google.com/p/seaside/issues/detail?id=643'.
		spec author: 'dkh'.
		spec timestamp: '2/28/2011 15:48'.
		spec 
			project: 'Grease Core' with: '1.0.4';
			project: 'Grease Core Tests' with: '1.0.4';
			project: 'Swazoo2' with: '2.2.0.3'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-pmm.89';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.114';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.71';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.24';
			package: 'RSS-Core' with: 'RSS-Core-pmm.65';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.99';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-pmm.108';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.108';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.87';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.710';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.148';
			package: 'Seaside-Email' with: 'Seaside-Email-pmm.19';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.74';
			package: 'Seaside-Examples' with: 'Seaside-Examples-pmm.22';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-pmm.22';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.134';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-pmm.21';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-pmm.21';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.100';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.35';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.63';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-DaleHenrichs.40';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-pmm.127';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.80';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.12';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-pmm.28';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.59';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-pmm.36';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-pmm.53';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.218';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.38';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-pmm.11';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.25';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-pmm.29';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.133';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-as.21';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-pmm.44';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-pmm.17';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-NickAger.4'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.8';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.22';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.67';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.12';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-pmm.47';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-pmm.10';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.28';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.18';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-dkh.14';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.4';
			project: 'Grease Slime Tests' with: '1.0.4'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'pharo1.2.x' do: [
		spec blessing: #'development'. ].

	spec for: #'pharo1.3.x' do: [
		spec blessing: #'development'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.244';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: #'stable'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-DaleHenrichs.73';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-DaleHenrichs.702';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.106';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.61';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.23';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.7';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-DaleHenrichs.8';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.16';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-NorbertHartl.9';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-DaleHenrichs.135';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-DaleHenrichs.14';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.3';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 09/02/2011 15:45'!
version30501: spec
	<version: '3.0.5.0.1' imports: #('3.0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '- pick up fix for Issue 674: WASwazooAdaptor decodes an already decoded URI
- http://code.google.com/p/seaside/issues/detail?id=674'.
		spec author: 'dkh'.
		spec timestamp: '08/31/2011 13:18:20'.
		spec 
			project: 'Grease Core' with: '1.0.5.1';
			project: 'Grease Core Tests' with: '1.0.5.1';
			project: 'Swazoo2' with: '2.3.0.0'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-pmm.89';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.118';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.75';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.24';
			package: 'RSS-Core' with: 'RSS-Core-pmm.65';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.99';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-pmm.108';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.108';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.87';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.712';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.148';
			package: 'Seaside-Email' with: 'Seaside-Email-pmm.19';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.74';
			package: 'Seaside-Examples' with: 'Seaside-Examples-pmm.22';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-pmm.22';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.138';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-pmm.21';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-pmm.21';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.100';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.35';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.63';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.41';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.128';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.80';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.12';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-pmm.28';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.59';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-pmm.36';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-pmm.53';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-lr.219';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.38';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-pmm.11';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.25';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-pmm.29';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.133';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.22';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-pmm.44';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-pmm.17';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-NickAger.4'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.22';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.68';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.12';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.50';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-pmm.10';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.29';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.19';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-dkh.14';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.5.1';
			project: 'Grease Slime Tests' with: '1.0.5.1'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'pharo1.2.x' do: [
		spec blessing: #'development'. ].

	spec for: #'pharo1.3.x' do: [
		spec blessing: #'development'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.244';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.4'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-JohanBrichau.77';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.712';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.106';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.62';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.23';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.7';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.11';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.16';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.12';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.140';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.3';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 08/09/2011 11:21'!
version3051: spec
	<version: '3.0.5.1' imports: #('3.0.5.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.0.5.1 (dkh.317):
- open 3.0.5.1 for development... GemStone-specific branch aimed at bypassing use of class instance variables (etc.) to allow the GemStone 3.0 version of Seaside to run against a read only SymbolDictionary. Some class instance variables are mapped to session temps and some are mapped to user-specific storage in UserGlobals.
- class instance variables in WADispatcher, WAFileHandler, WAFileLibrary, WASharedConfiguration, WASystemConfiguration, WAEnvironment and WAAdmin mapped to persistent per-user storage
- class instance variables in WAKeyGenerator mapped to session state
- fix WAGemStoneMaintenanceTask class>>maintenanceTaskMarkForCollect will work in GemStone 2.x and 3.x
3.0.5.1 (dkh.318):
- pick up fix for Issue 674: WASwazooAdaptor decodes an already decoded URI
- http://code.google.com/p/seaside/issues/detail?id=674'.
		spec author: 'dkh'.
		spec timestamp: '08/09/2011 11:21:39'.
		spec 
			project: 'Grease Core' with: '1.0.5.1';
			project: 'Grease Core Tests' with: '1.0.5.1';
			project: 'Swazoo2' with: '2.3.0.0'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-pmm.89';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.118';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.75';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.24';
			package: 'RSS-Core' with: 'RSS-Core-pmm.65';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.99';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-pmm.108';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.108';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.87';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.712';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.148';
			package: 'Seaside-Email' with: 'Seaside-Email-pmm.19';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.74';
			package: 'Seaside-Examples' with: 'Seaside-Examples-pmm.22';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-pmm.22';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.138';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-pmm.21';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-pmm.21';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.100';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.35';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.63';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.41';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.128';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.80';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.12';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-pmm.28';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.59';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-pmm.36';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-pmm.53';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-lr.219';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.38';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-pmm.11';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.25';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-pmm.29';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.133';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.22';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-pmm.44';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-pmm.17';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-NickAger.4'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.22';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.68';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.12';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.50';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-pmm.10';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.29';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.19';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-dkh.14';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.5.1';
			project: 'Grease Slime Tests' with: '1.0.5.1'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'pharo1.2.x' do: [
		spec blessing: #'development'. ].

	spec for: #'pharo1.3.x' do: [
		spec blessing: #'development'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.4'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-JohanBrichau.77';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.713';
			package: 'Seaside-Environment' with: 'Seaside-Environment.gemstone-dkh.75';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core.gemstone-dkh.19';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.106';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.62';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.23';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.7';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.16';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.12';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.140';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.3';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 9/20/2011 10:26'!
version305: spec
	<version: '3.0.5' imports: #('3.0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- see http://code.google.com/p/seaside/wiki/Seaside305Changelog for details
3.0.5 (dkh.308):
- Move GRGemStonePlatformTest>>testFileLibrary to WAGemStoneFileLibraryTest ... reference to WAFileLibrary belongs in a Seaside package
- fix Issue 248: GRGemStonePlatform>>seasideDeliverEmailMessage is broken
  http://code.google.com/p/glassdb/issues/detail?id=248
- pick up Seaside-GemStone-Tools-Production-PaulDeBruicker.10'.
		spec author: 'dkh'.
		spec timestamp: '05/17/2011 19:04:12'.
		spec 
			project: 'Grease Core' with: '1.0.5';
			project: 'Grease Core Tests' with: '1.0.5';
			project: 'Swazoo2' with: '2.3.0.0'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-pmm.89';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.118';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.75';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.24';
			package: 'RSS-Core' with: 'RSS-Core-pmm.65';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.24';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.99';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-pmm.108';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.108';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.87';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.712';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.148';
			package: 'Seaside-Email' with: 'Seaside-Email-pmm.19';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.74';
			package: 'Seaside-Examples' with: 'Seaside-Examples-pmm.22';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-pmm.22';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.72';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.138';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.18';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-pmm.21';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-pmm.21';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.100';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.35';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.63';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-DaleHenrichs.40';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.128';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.80';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.12';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-pmm.28';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.59';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-pmm.36';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-pmm.53';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-NickAger.31';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-lr.219';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.38';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-pmm.11';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.25';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-pmm.29';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.133';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.22';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-pmm.44';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-pmm.17';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.9';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-NickAger.4'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.22';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.68';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.12';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.50';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-pmm.10';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.29';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.7';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.19';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-dkh.14';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.12'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.5';
			project: 'Grease Slime Tests' with: '1.0.5'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.78';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.244';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.3'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.76';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.712';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-DaleHenrichs.106';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-DaleHenrichs.61';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.23';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.7';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.9';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.16';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-PaulDeBruicker.10';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.139';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.3';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 10/18/2011 15:52'!
version3061: spec
	<version: '3.0.6.1' imports: #('3.0.6.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.0.6.1 (dkh.333) [GemStone]:
- fix Issue 289: PositionableStream>>seasideNextLine does not respecte non-lf next lines.
  http://code.google.com/p/glassdb/issues/detail?id=289
3.0.6.1 (dkh.334):
- remove the GemStone method seasideNextLine and add a test for Issue 289
3.0.6.1 (dkh.335):
- pick up fix for Issue 298: FastCGI parsing of content-length header fails on present but empty header
  http://code.google.com/p/glassdb/issues/detail?id=298
3.0.6.1 (dkh.336):
- fix Issue 694: Swazoo adapter does not respect Request URIs ending in slash.
  http://code.google.com/p/seaside/issues/detail?id=694
3.0.6.1 (dkh.337):
- fix Issue 130: remote breakpoints don''t work
  http://code.google.com/p/glassdb/issues/detail?id=130
3.0.6.1 (dkh.338):
- GemStone 3.0.1 fix for Issue 130: remote breakpoints don''t work
  http://code.google.com/p/glassdb/issues/detail?id=130
- fix Issue 636: expected exception behavior WAWalkbackErrorHandler not portable (and not ANSI compliant) [backport fix from Seaside3.1]
  http://code.google.com/p/seaside/issues/detail?id=636
- fix Issue 291: Maintenance Gem Topaz Exit [Seaside 3.0 / GemStone 3.0]
  http://code.google.com/p/glassdb/issues/detail?id=291
3.0.6.1 (dkh.339):
- back off a bit on the fix for Issue 130 ... make cross platform error handlers a little easier to manage
3.0.6.1 (dkh.340): [GEMSTONE]
- in WAGemStoneProductionErrorHandler, a Breakpoint should be caught, continuation snapped off and saved, and then the breakpoint should be resumed with no message ...'.
		spec author: 'dkh'.
		spec timestamp: '10/18/2011 15:51'.
		spec 
			project: 'Grease Core' with: '1.0.6.1';
			project: 'Grease Core Tests' with: '1.0.6.1';
			project: 'Swazoo2' with: '2.3.0.0';
			project: 'Zinc' with: '1.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.90';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.121';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.80';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.25';
			package: 'RSS-Core' with: 'RSS-Core-lr.67';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.26';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.102';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.111';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.117';
			package: 'Seaside-Component' with: 'Seaside-Component-jok.92';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.750';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.156';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.21';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.76';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.23';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.23';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.73';
			package: 'Seaside-Session' with: 'Seaside-Session-lr.142';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.19';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.26';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.25';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.108';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.39';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.63';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.42';
			package: 'Zinc-Seaside' with: 'Zinc-Seaside-lr.18';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.130';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.82';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.13';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.30';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.61';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.39';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-dkh.58';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-jok.33';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.253';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.43';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.14';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.27';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-spd.33';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.142';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.26';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.49';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.18';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.10';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-lr.6'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.23';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.70';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-lr.13';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-pmm.55';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.13';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.38';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.8';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.25';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-lr.16';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.13'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.6';
			project: 'Grease Slime Tests' with: '1.0.6'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'FastCGI' with: '0.235';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.4'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.81';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.753';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.5';
			package: 'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-dkh.119';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.63';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.26';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.11';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.12';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.20';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.13';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone-dkh.74';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.143';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.3';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone-dkh.12'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 10/18/2011 21:38'!
version3062: spec
	<version: '3.0.6.2' imports: #('3.0.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'pick up Grease 1.0.6.2 which has the fixes for RFB renaming'.
		spec author: 'dkh'.
		spec timestamp: '10/18/2011 16:11'.
		spec 
			project: 'Grease Core' with: '1.0.6.2';
			project: 'Grease Core Tests' with: '1.0.6.2';
			project: 'Swazoo2' with: '2.3.0.0';
			project: 'Zinc' with: '1.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.90';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.121';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.80';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.25';
			package: 'RSS-Core' with: 'RSS-Core-lr.67';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.26';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.102';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.111';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.117';
			package: 'Seaside-Component' with: 'Seaside-Component-jok.92';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.750';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.156';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.21';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.76';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.23';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.23';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.73';
			package: 'Seaside-Session' with: 'Seaside-Session-lr.142';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.19';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.26';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.25';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.108';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.39';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.63';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.41';
			package: 'Zinc-Seaside' with: 'Zinc-Seaside-lr.18';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.130';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.82';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.13';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.30';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.61';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.39';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-pmm.57';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-jok.33';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.253';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.43';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.14';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.27';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-spd.33';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.142';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.26';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.49';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.18';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.10';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-lr.6'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.23';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.70';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-lr.13';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-pmm.55';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.13';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.38';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.8';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.25';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-lr.16';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.13'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.6.2';
			project: 'Grease Slime Tests' with: '1.0.6.2'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.81';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'pharo1.1.x' do: [
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80'. ].
	
	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80'. ].
	
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.4'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.81';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.751';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-dkh.118';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.62';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.23';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.7';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.12';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.20';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.12';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.143';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.3';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 2/3/2012 09:49'!
version3063: spec
	<version: '3.0.6.3' imports: #('3.0.6.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '3.0.6.1 (dkh.333) [GemStone]:
- fix Issue 289: PositionableStream>>seasideNextLine does not respecte non-lf next lines.
  http://code.google.com/p/glassdb/issues/detail?id=289
3.0.6.1 (dkh.334):
- remove the GemStone method seasideNextLine and add a test for Issue 289
3.0.6.1 (dkh.335):
- pick up fix for Issue 298: FastCGI parsing of content-length header fails on present but empty header
  http://code.google.com/p/glassdb/issues/detail?id=298
3.0.6.1 (dkh.336):
- fix Issue 694: Swazoo adapter does not respect Request URIs ending in slash.
  http://code.google.com/p/seaside/issues/detail?id=694
3.0.6.1 (dkh.337):
- fix Issue 130: remote breakpoints don''t work
  http://code.google.com/p/glassdb/issues/detail?id=130
3.0.6.1 (dkh.338):
- GemStone 3.0.1 fix for Issue 130: remote breakpoints don''t work
  http://code.google.com/p/glassdb/issues/detail?id=130
- fix Issue 636: expected exception behavior WAWalkbackErrorHandler not portable (and not ANSI compliant) [backport fix from Seaside3.1]
  http://code.google.com/p/seaside/issues/detail?id=636
- fix Issue 291: Maintenance Gem Topaz Exit [Seaside 3.0 / GemStone 3.0]
  http://code.google.com/p/glassdb/issues/detail?id=291
3.0.6.1 (dkh.339):
- back off a bit on the fix for Issue 130 ... make cross platform error handlers a little easier to manage
3.0.6.1 (dkh.340): [GEMSTONE]
- in WAGemStoneProductionErrorHandler, a Breakpoint should be caught, continuation snapped off and saved, and then the breakpoint should be resumed with no message ...
- open 3.0.6.3 for GemStone development ... merged 3.0.6.1 and 3.0.6.2
3.0.6.3 (dkh.346):
- update message in WALotsaLinksGemStoneFunctionalTest>>renderExplanationOn: for GemStone 3.0.1
- update message in WAFlowFunctionalTest>>renderContentOn: for GemStone 3.0.1
- log stack to log file when saving exception continuation in case commit later fails ... WAErrorHandler>>saveExceptionContinuation
- WAHandleAbortWouldLoseDataToolFilter>>handleFiltered: transaction logic fixed
3.0.6.3 (dkh.347):
- adjust test for Issue 694
3.0.6.3 (dkh.348):
- pick up Grease 1.0.6.3
3.0.6.3 (dkh.349):
- clean up WAFlowPlatformTest issues when tests run from topaz.
- Grease 1.0.6.4 in support of GemStone/S 2.4.5
3.0.6.3 (dkh.350):
- fix Issue 312: bcc mail recipients not honored
  http://code.google.com/p/glassdb/issues/detail?id=312
3.0.6.3 (dkh.351):
- WARequest>>printOn: shouldn''t fail if method is nil ... GemStone only 
3.0.6.3 (dkh.353):
- Zinc 1.1 should be used with ... GemStone only'.
		spec timestamp: '12/2/2011 09:49'.
		spec 
			project: 'Grease Core' with: '1.0.6.4';
			project: 'Grease Core Tests' with: '1.0.6.4';
			project: 'Swazoo2' with: '2.3.0.0';
			project: 'Zinc' with: '1.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.90';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.121';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.80';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.25';
			package: 'RSS-Core' with: 'RSS-Core-lr.67';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.26';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.102';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.111';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.117';
			package: 'Seaside-Component' with: 'Seaside-Component-jok.92';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.750';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.156';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.21';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.76';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.23';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.23';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.73';
			package: 'Seaside-Session' with: 'Seaside-Session-lr.142';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.19';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.26';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.25';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.108';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.39';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.63';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.42';
			package: 'Zinc-Seaside' with: 'Zinc-Seaside-lr.18';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.130';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.82';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.13';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.30';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.61';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.39';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-dkh.58';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-jok.33';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.253';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.43';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.14';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.27';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-dkh.34';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.142';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.26';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.49';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.18';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.10';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-lr.6'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.23';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.70';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-lr.13';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-pmm.55';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.13';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.38';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.8';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.25';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-lr.16';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.13'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.6.4';
			project: 'Grease Slime Tests' with: '1.0.6.4'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.81';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'pharo1.1.x' do: [
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80'. ].
	
	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80'. ].
	
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'FastCGI' with: '0.235';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.4';
			project: 'Zinc' with: '1.1'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.81';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.754';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.5';
			package: 'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-dkh.119';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.63';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.27';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.12';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-topa.13';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.20';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.13';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone-dkh.74';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.143';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.4';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.12';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone-dkh.13'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'StephaneDucasse 3/17/2012 18:49'!
version3064: spec
	<version: '3.0.6.4' imports: #('3.0.6.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '3.0.6.4: make sure that the right version of KomHttpServer is loaded for Pharo 1.4 - Kom Logger referred to TranscriptStream which was deprecated in 1.3'.
		spec timestamp: '16/3/2012'.
		spec 
			project: 'Grease Core' with: '1.0.6.4';
			project: 'Grease Core Tests' with: '1.0.6.4';
			project: 'Swazoo2' with: '2.3.0.0';
			project: 'Zinc' with: '1.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.90';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.121';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.80';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.25';
			package: 'RSS-Core' with: 'RSS-Core-lr.67';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.26';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.102';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.111';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.117';
			package: 'Seaside-Component' with: 'Seaside-Component-jok.92';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.750';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.156';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.21';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.76';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.23';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.23';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.73';
			package: 'Seaside-Session' with: 'Seaside-Session-lr.142';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.19';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.26';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.25';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.108';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.39';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.63';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.42';
			package: 'Zinc-Seaside' with: 'Zinc-Seaside-lr.18';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.130';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.82';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.13';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.30';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.61';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.39';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-dkh.58';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-jok.33';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.253';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.43';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.14';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.27';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-dkh.34';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.142';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.26';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.49';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.18';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.10';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-lr.6'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.23';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.70';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-lr.13';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-pmm.55';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.13';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.38';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.8';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.25';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-lr.16';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.13'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.6.4';
			project: 'Grease Slime Tests' with: '1.0.6.4'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.81';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].
	

	spec for: #'pharo1.4.x' do: [
		spec project: 'Kom' with: '1.1.0'].
	
	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80'. ].
	
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'FastCGI' with: '0.235';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.4';
			project: 'Zinc' with: '1.1'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.81';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.754';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.5';
			package: 'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-dkh.119';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.63';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.27';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.12';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-topa.13';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.20';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.13';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone-dkh.74';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.143';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.4';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.12';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone-dkh.13'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 9/20/2011 10:22'!
version306: spec
	<version: '3.0.6' imports: #('3.0.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '3.0.6 (dkh.323):
- open 3.0.6 for development
- update to latest packages (http://code.google.com/p/seaside/wiki/Seaside306Changelog)
- update GRPlatform seaside version to 3.0.6
3.0.6 (dkh.324):
- add Zinc adaptor as part of Core
3.0.6 (dkh.325) [GEMSTONE]:
- Swazoo 2.2.0.4 for GemStone
- pick up recent GemStone packages
3.0.6 (dkh.326) [GEMSTONE]:
- merge JQuery-UI.gemstone-JohanBrichau.77, JQuery-UI-lr.80
- merge Seaside-Canvas.gemstone-DaleHenrichs.106, Seaside-Canvas-pmm.117
- merge Seaside-Core.gemstone-dkh.714, Seaside-Core-dkh.750
- merge Seaside-Session.gemstone-dkh.140, Seaside-Session-lr.142
- pick up GsCore 0.245
3.0.6 (dkh.327) [GEMSTONE]:
- exclude Zinc-Seaside (Zinc adaptor) from default group
- gemstone-specific bugfix for Issue 658: Seaside-Email should use request handler for configuration look up
  http://code.google.com/p/seaside/issues/detail?id=658
3.0.6 (dkh.328) [GEMSTONE]:
- fix Issue 274: Seaside-GemStone-ServiceTask
  http://code.google.com/p/glassdb/issues/detail?id=274
- fix Issue 273: Squeak-dkh.258 gives FastCGI error: InterpreterError 2192: End of stream was encountered in ReadStream
  http://code.google.com/p/glassdb/issues/detail?id=273
- fix Issue 272: GRGemStonePlatform>>seasideDeliverEmailMessage includes too much in mail message and missing subject
  http://code.google.com/p/glassdb/issues/detail?id=272'.
		spec author: 'dkh'.
		spec timestamp: '09/02/2011 17:07:39'.
		spec 
			project: 'Grease Core' with: '1.0.6';
			project: 'Grease Core Tests' with: '1.0.6';
			project: 'Swazoo2' with: '2.3.0.0';
			project: 'Zinc' with: '1.2'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.90';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.121';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.80';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.25';
			package: 'RSS-Core' with: 'RSS-Core-lr.67';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.26';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.102';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.111';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.117';
			package: 'Seaside-Component' with: 'Seaside-Component-jok.92';
			package: 'Seaside-Core' with: 'Seaside-Core-dkh.750';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.156';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.21';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.76';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.23';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-lr.23';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.73';
			package: 'Seaside-Session' with: 'Seaside-Session-lr.142';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.19';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.26';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.25';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.108';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.39';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.63';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-jf.19';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.41';
			package: 'Zinc-Seaside' with: 'Zinc-Seaside-lr.18';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-lr.130';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.82';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.13';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.30';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.61';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.39';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-pmm.57';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-jok.33';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.253';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.43';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.14';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.27';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-spd.33';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.142';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.26';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.49';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.18';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.10';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-lr.6'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.23';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.70';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-lr.13';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-pmm.55';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.13';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser-lr.6';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.38';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.8';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.25';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-lr.16';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.13'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.6';
			project: 'Grease Slime Tests' with: '1.0.6'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'FastCGI' with: '0.234';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.4'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.81';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.751';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-DaleHenrichs.4';
			package: 'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-dkh.118';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.62';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-DaleHenrichs.23';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-DaleHenrichs.7';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-dkh.12';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.20';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.12';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.143';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-DaleHenrichs.3';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-DaleHenrichs.11'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'dkh 09/25/2012 09:44'!
version3071: spec
	<version: '3.0.7.1' imports: #('3.0.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '3.0.7.1 (dkh.374)
- port Seaside3.0.7 to GemStone 3.1
- GSProcess>>_callUnwindBlocks not used in GemStone 3.1
3.0.7.1 (dkh.375):
- need to use Grease 1.0.7.1 for GemStone 3.1
3.0.7.1 (dkh.377)
- fix test issue for GemStone related to issue 353 - UTF8 tests failing in 3.1.0.1
  http://code.google.com/p/glassdb/issues/detail?id=353'.
		spec 
			project: 'Grease Core' with: '1.0.7.2';
			project: 'Grease Core Tests' with: '1.0.7.2';
			project: 'Swazoo2' with: '2.3.0.0';
			project: 'Zinc' with: #'stable'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.90';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.123';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.80';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.25';
			package: 'RSS-Core' with: 'RSS-Core-lr.67';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.26';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.102';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.111';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.117';
			package: 'Seaside-Component' with: 'Seaside-Component-jok.92';
			package: 'Seaside-Core' with: 'Seaside-Core-NickAger.768';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.156';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.21';
			package: 'Seaside-Environment' with: 'Seaside-Environment-NickAger.77';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.23';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-pmm.28';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.73';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.157';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.19';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.26';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.25';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-NickAger.113';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-NickAger.40';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.63';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-pmm.20';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.42';
			package: 'Zinc-Seaside' with: 'Zinc-Seaside-SvenVanCaekenberghe.22';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-NickAger.132';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.82';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.13';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.30';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.61';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.39';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-dkh.58';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-jok.33';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-NickAger.257';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.43';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.14';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.27';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-dkh.34';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.142';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.28';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.49';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.18';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.10';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-lr.6'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.23';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.70';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-NickAger.16';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.57';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.13';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser.pharoOB-NickAger.7';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-NickAger.39';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.8';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.25';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-pmm.18';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.13'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.7.2';
			project: 'Grease Slime Tests' with: '1.0.7.2'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.82';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'pharo1.4.x' do: [
		spec project: 'Kom' with: '1.1.0'. ].

	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.246';
			project: 'FastCGI' with: '0.235';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.4';
			project: 'Zinc' with: '1.1'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.81';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.26';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.769';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.5';
			package: 'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-dkh.119';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.63';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.27';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.12';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-topa.13';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.20';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.13';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone-dkh.74';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.158';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.4';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.12';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone-dkh.13'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
	spec for: #'gs3.1.x' do: [
		spec package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow.310-dkh.12' ].
	spec for: #'gs3.2.x' do: [
		spec package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow.310-dkh.12' ]
	! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'NickAger 4/5/2012 18:11'!
version307: spec
	<version: '3.0.7' imports: #('3.0.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'release 3.0.7 see http://code.google.com/p/seaside/wiki/Seaside307Changelog'.
		spec 
			project: 'Grease Core' with: '1.0.7';
			project: 'Grease Core Tests' with: '1.0.7';
			project: 'Swazoo2' with: '2.3.0.0';
			project: 'Zinc' with: #'stable'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-lr.90';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.123';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.80';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.25';
			package: 'RSS-Core' with: 'RSS-Core-lr.67';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.26';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.102';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.111';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.117';
			package: 'Seaside-Component' with: 'Seaside-Component-jok.92';
			package: 'Seaside-Core' with: 'Seaside-Core-NickAger.768';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.156';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.21';
			package: 'Seaside-Environment' with: 'Seaside-Environment-NickAger.77';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.23';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-pmm.28';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.73';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.157';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.19';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.26';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.25';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-NickAger.113';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-NickAger.40';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.63';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-pmm.20';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.42';
			package: 'Zinc-Seaside' with: 'Zinc-Seaside-SvenVanCaekenberghe.22';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-NickAger.132';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.82';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.13';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.30';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.61';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.39';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-dkh.58';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-jok.33';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-NickAger.257';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.43';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.14';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.27';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-dkh.34';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.142';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.28';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.49';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.18';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.10';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-lr.6'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.23';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.70';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-NickAger.16';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.57';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.13';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser.pharoOB-NickAger.7';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-NickAger.39';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.8';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.25';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-pmm.18';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.13'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.7';
			project: 'Grease Slime Tests' with: '1.0.7'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.82';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'pharo1.4.x' do: [
		spec project: 'Kom' with: '1.1.0'. ].

	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'FastCGI' with: '0.235';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.4';
			project: 'Zinc' with: '1.1'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.81';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.769';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.5';
			package: 'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-dkh.119';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.63';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.27';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.12';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-topa.13';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.20';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.13';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone-dkh.74';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.158';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.4';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.12';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone-dkh.13'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

!ConfigurationOfSeaside30 methodsFor: 'versions' stamp: 'JohanBrichau 3/31/2013 20:53'!
version308: spec
	<version: '3.0.8' imports: #('3.0.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'opened'.
		spec 
			project: 'Grease Core' with: '1.0.8';
			project: 'Grease Core Tests' with: '1.0.8';
			project: 'Swazoo2' with: '2.3.0.0';
			project: 'Zinc' with: #'stable'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-pmm.92';
			package: 'JQuery-Core' with: 'JQuery-Core-lr.123';
			package: 'JQuery-UI' with: 'JQuery-UI-lr.80';
			package: 'Prototype-Core' with: 'Prototype-Core-lr.25';
			package: 'RSS-Core' with: 'RSS-Core-lr.67';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.26';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.102';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-lr.111';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-JohanBrichau.118';
			package: 'Seaside-Component' with: 'Seaside-Component-jok.92';
			package: 'Seaside-Core' with: 'Seaside-Core-JohanBrichau.769';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.156';
			package: 'Seaside-Email' with: 'Seaside-Email-lr.21';
			package: 'Seaside-Environment' with: 'Seaside-Environment-NickAger.77';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.23';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.23';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-pmm.28';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-lr.73';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.157';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-lr.19';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-lr.26';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-lr.25';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-NickAger.113';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-NickAger.40';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.66';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-pmm.20';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.42';
			package: 'Zinc-Seaside' with: 'Zinc-Seaside-SvenVanCaekenberghe.22';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-NickAger.132';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-pmm.82';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-lr.13';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.30';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.61';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-lr.39';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-dkh.58';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-jok.33';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-NickAger.257';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.43';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.14';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-lr.27';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-lr.9';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-dkh.34';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.142';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.28';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.11';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-lr.49';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-lr.18';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-lr.10';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-lr.6'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.33'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-lr.51';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.23';
			package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6';
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-DaleHenrichs.9';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-lr.70';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-lr.3';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-NickAger.16';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-lr.57';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-lr.13';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser.pharoOB-NickAger.7';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-NickAger.39';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.8';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-JohanBrichau.26';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-pmm.24';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-lr.13'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.0.8';
			project: 'Grease Slime Tests' with: '1.0.8'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.82';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-JohanBrichau.43'. ].

	spec for: #'pharo1.4.x' do: [
		spec project: 'Kom' with: '1.1.0'. ].

	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.246';
			project: 'FastCGI' with: '0.235';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.4';
			project: 'Zinc' with: '1.1'.
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4';
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.81';
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-dkh.26';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.769';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.5';
			package: 'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-dkh.119';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.63';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.27';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.12';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-topa.13';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.20';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.13';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone-dkh.74';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.158';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.4';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.12';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone-dkh.13'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
	spec for: #'gs3.1.x' do: [
		spec package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow.310-dkh.12' ].
	spec for: #'gs3.2.x' do: [
		spec package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow.310-dkh.12' ]
	! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'pmm 8/28/2012 11:59'!
version310: spec
	<version: '3.1.0' imports: #('3.1.0-adaptors' '3.1.0-comet' '3.1.0-common' '3.1.0-filesystem' '3.1.0-gemstone' '3.1.0-javascript' '3.1.0-jquery' '3.1.0-jqueryui' '3.1.0-json' '3.1.0-ob' '3.1.0-pharo' '3.1.0-rss' '3.1.0-scriptaculous' '3.1.0-welcome')>
! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'KenTreis 01/24/2013 11:27'!
version310adaptors: spec
	<version: '3.1.0-adaptors' imports: #('3.1.0-adaptors-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec
			project: 'Swazoo2' with: '2.3.0.0';
			project: 'Zinc Project' with: #'stable'.
		spec 
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-pmm.20';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.43';
			package: 'Zinc-Seaside' with: 'Zinc-Seaside-SvenVanCaekenberghe.32' ].
		
	spec for: #'pharo' do: [
		spec
			package: 'KomHttpServerLight' with: 'KomHttpServerLight-pmm.11';
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.73';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14' ].
		
	spec for: #'squeak' do: [
		spec
			package: 'WebClient-Seaside' with: 'WebClient-Seaside-ar.10' ].
		
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'FastCGI Project' with: '0.235';
			project: 'Swazoo2' with: '2.2.0.4';
			project: 'Zinc Project' with: '1.1'.
		spec
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.5';
			package: 'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.4' ]
! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:35'!
version310comet: spec
	<version: '3.1.0-comet' imports: #('3.1.0-comet-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-pmm.54';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.25';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11' ].
		
	spec for: #'pharo' do: [
		spec package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6' ]! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:35'!
version310common: spec
	<version: '3.1.0-common' imports: #('3.1.0-common-baseline')>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec 
			project: 'Grease' with: '1.1.0';
			project: 'Grease Core Tests' with: '1.1.0'.
		spec
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.122';
			package: 'Seaside-Component' with: 'Seaside-Component-pmm.94';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.773';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.161';
			package: 'Seaside-Email' with: 'Seaside-Email-pmm.22';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.79';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.23';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.24';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-pmm.31';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.83';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.165';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.22';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-pmm.29';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.114';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-dkh.58';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-jok.33';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.258';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.44';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.14';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.28';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-pmm.10';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-pmm.35';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.149';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.33';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.13';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.69';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-jf.21';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-pmm.12' ]! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:36'!
version310filesystem: spec
	<version: '3.1.0-filesystem' imports: #('3.1.0-filesystem-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'SPort2' with: '2.31'.
		spec 
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13' ]
! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:36'!
version310gemstone: spec
	<version: '3.1.0-gemstone' imports: #('3.1.0-gemstone-baseline' )>
	
	spec for: #'gemstone' do: [
		spec blessing: #'development'.
		spec 
			project: 'GsCore' with: '0.245'.
		spec
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.769';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-dkh.119';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.63';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.27';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.12';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-topa.13';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.20';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.13';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone-dkh.74';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.158';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.4';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.12';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone-dkh.13' ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:36'!
version310javascript: spec
	<version: '3.1.0-javascript' imports: #('3.1.0-javascript-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-pmm.95';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.68' ].
		
	spec for: #'squeakCommon' do: [
		spec
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-pmm.10';
			package: 'Javascript-Pharo20-Core' with: 'Javascript-Pharo20-Core-pmm.3';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1' ].
		
	spec for: #'gemstone' do: [
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4' ]! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:36'!
version310jquery: spec
	<version: '3.1.0-jquery' imports: #('3.1.0-jquery-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec 
			package: 'JQuery-Core' with: 'JQuery-Core-pmm.125';
			package: 'JQuery-JSON' with: 'JQuery-JSON-pmm.1';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-pmm.135';
			package: 'JQuery-Tests-JSON' with: 'JQuery-Tests-JSON-pmm.1' ]
! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:36'!
version310jqueryui: spec
	<version: '3.1.0-jqueryui' imports: #('3.1.0-jqueryui-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec 
			package: 'JQuery-UI' with: 'JQuery-UI-lr.83';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.83' ].
		
	spec for: #'gemstone' do: [
		spec 
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.81' ]
! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:36'!
version310json: spec
	<version: '3.1.0-json' imports: #('3.1.0-json-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec 
			package: 'Seaside-JSON-Core' with: 'Seaside-JSON-Core-pmm.15';
			package: 'Seaside-Tests-JSON' with: 'Seaside-Tests-JSON-pmm.7' ].
		
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Seaside-Pharo-JSON-Core' with: 'Seaside-Pharo-JSON-Core-pmm.1' ]! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:36'!
version310ob: spec
	<version: '3.1.0-ob' imports: #('3.1.0-ob-baseline' )>
		
	spec for: #'squeakCommon' do: [
		spec blessing: #'development'.
		spec
			project: 'OB' with: #'stable'.
		spec
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser.pharoOB-NickAger.7';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-pmm.27' ].
		
	spec for: #'gemstone' do: [
		spec
			project: 'OB' with: #'stable'.
		spec
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-pmm.27' ]
! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:36'!
version310pharo: spec
	<version: '3.1.0-pharo' imports: #('3.1.0-pharo-baseline' )>
	
	spec for: #'squeakCommon' do: [
		spec blessing: #'development'.
		spec
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-pmm.4';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.21';
			package: 'Seaside-Pharo20-Core' with: 'Seaside-Pharo20-Core-pmm.3';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-pmm.60';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-pmm.14';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.44';
			package: 'Seaside-Pharo20-Tools-Web' with: 'Seaside-Pharo20-Tools-Web-SvenVanCaekenberghe.1';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.8';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.28';
			package: 'Seaside-Tests-Pharo20-Core' with: 'Seaside-Tests-Pharo20-Core-pmm.2';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-pmm.23';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-pmm.14' ].
		
	spec for: #'pharo1.x' do: [
		spec 
			project: 'Grease Slime' with: '1.1.0';
			project: 'Grease Slime Tests' with: '1.1.0'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.82';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42' ].

	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80' ].! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:36'!
version310rss: spec
	<version: '3.1.0-rss' imports: #('3.1.0-rss-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec 
			package: 'RSS-Core' with: 'RSS-Core-pmm.68';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.26';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.30' ]
! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:36'!
version310scriptaculous: spec
	<version: '3.1.0-scriptaculous' imports: #('3.1.0-scriptaculous-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec 
			package: 'Prototype-Core' with: 'Prototype-Core-pmm.27';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-pmm.16';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.103';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.62';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-pmm.112';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-pmm.40' ]
! !

!ConfigurationOfSeaside30 methodsFor: 'versions-31' stamp: 'dkh 9/10/2012 14:36'!
version310welcome: spec
	<version: '3.1.0-welcome' imports: #('3.1.0-welcome-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec 
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.41';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-lr.6' ].
		
	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1' ].


	spec for: #'pharo' do: [
		spec 
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2' ].
		
	spec for: #'gemstone' do: [
		spec
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1' ]
! !
